#[non_exhaustive]pub enum PlanUpdateContent {
Items(PlanItems),
File(PlanFile),
Markdown(PlanMarkdown),
}Available on crate feature
unstable_plan_operations only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Updated content for a plan.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Items(PlanItems)
Structured plan entries.
File(PlanFile)
A URI pointing to a file containing the plan.
Markdown(PlanMarkdown)
Raw markdown content for the plan.
Implementations