#[non_exhaustive]pub struct AgentMethodNames {Show 28 fields
pub initialize: &'static str,
pub authenticate: &'static str,
pub providers_list: &'static str,
pub providers_set: &'static str,
pub providers_disable: &'static str,
pub session_new: &'static str,
pub session_load: &'static str,
pub session_set_mode: &'static str,
pub session_set_config_option: &'static str,
pub session_prompt: &'static str,
pub session_cancel: &'static str,
pub mcp_message: &'static str,
pub session_list: &'static str,
pub session_delete: &'static str,
pub session_fork: &'static str,
pub session_resume: &'static str,
pub session_close: &'static str,
pub logout: &'static str,
pub nes_start: &'static str,
pub nes_suggest: &'static str,
pub nes_accept: &'static str,
pub nes_reject: &'static str,
pub nes_close: &'static str,
pub document_did_open: &'static str,
pub document_did_change: &'static str,
pub document_did_close: &'static str,
pub document_did_save: &'static str,
pub document_did_focus: &'static str,
}Expand description
Names of all methods that agents handle.
Provides a centralized definition of method names used in the protocol.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.initialize: &'static strMethod for initializing the connection.
authenticate: &'static strMethod for authenticating with the agent.
providers_list: &'static strunstable_llm_providers only.Method for listing configurable providers.
providers_set: &'static strunstable_llm_providers only.Method for setting provider configuration.
providers_disable: &'static strunstable_llm_providers only.Method for disabling a provider.
session_new: &'static strMethod for creating a new session.
session_load: &'static strMethod for loading an existing session.
session_set_mode: &'static strMethod for setting the mode for a session.
session_set_config_option: &'static strMethod for setting a configuration option for a session.
session_prompt: &'static strMethod for sending a prompt to the agent.
session_cancel: &'static strNotification for cancelling operations.
mcp_message: &'static strunstable_mcp_over_acp only.Method for exchanging MCP-over-ACP messages.
session_list: &'static strMethod for listing existing sessions.
session_delete: &'static strMethod for deleting an existing session.
session_fork: &'static strunstable_session_fork only.Method for forking an existing session.
session_resume: &'static strMethod for resuming an existing session.
session_close: &'static strMethod for closing an active session.
logout: &'static strMethod for logging out of an authenticated session.
nes_start: &'static strunstable_nes only.Method for starting an NES session.
nes_suggest: &'static strunstable_nes only.Method for requesting a suggestion.
nes_accept: &'static strunstable_nes only.Notification for accepting a suggestion.
nes_reject: &'static strunstable_nes only.Notification for rejecting a suggestion.
nes_close: &'static strunstable_nes only.Method for closing an NES session.
document_did_open: &'static strunstable_nes only.Notification for document open events.
document_did_change: &'static strunstable_nes only.Notification for document change events.
document_did_close: &'static strunstable_nes only.Notification for document close events.
document_did_save: &'static strunstable_nes only.Notification for document save events.
document_did_focus: &'static strunstable_nes only.Notification for document focus events.