#[non_exhaustive]pub struct Annotations {
pub audience: Option<Vec<Role>>,
pub last_modified: Option<String>,
pub priority: Option<f64>,
pub meta: Option<Meta>,
}Expand description
Optional annotations for the client. The client can use annotations to inform how objects are used or displayed
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.audience: Option<Vec<Role>>Intended recipients for this content, such as the user or assistant.
last_modified: Option<String>Timestamp indicating when the underlying resource was last modified.
priority: Option<f64>Relative importance of this content when clients choose what to surface.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl Annotations
impl Annotations
Sourcepub fn audience(self, audience: impl IntoOption<Vec<Role>>) -> Self
pub fn audience(self, audience: impl IntoOption<Vec<Role>>) -> Self
Sets or clears the optional audience field.
Sourcepub fn last_modified(self, last_modified: impl IntoOption<String>) -> Self
pub fn last_modified(self, last_modified: impl IntoOption<String>) -> Self
Sets or clears the optional lastModified field.
Sourcepub fn priority(self, priority: impl IntoOption<f64>) -> Self
pub fn priority(self, priority: impl IntoOption<f64>) -> Self
Sets or clears the optional priority field.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility