#[non_exhaustive]pub struct AuthMethodAgent {
pub id: AuthMethodId,
pub name: String,
pub description: Option<String>,
pub meta: Option<Meta>,
}Expand description
Agent handles authentication itself.
This is the default authentication method type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: AuthMethodIdUnique identifier for this authentication method.
name: StringHuman-readable name of the authentication method.
description: Option<String>Optional description providing more details about this authentication method.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl AuthMethodAgent
impl AuthMethodAgent
pub fn new(id: impl Into<AuthMethodId>, name: impl Into<String>) -> Self
Sourcepub fn description(self, description: impl IntoOption<String>) -> Self
pub fn description(self, description: impl IntoOption<String>) -> Self
Optional description providing more details about this authentication method.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility