#[non_exhaustive]pub struct CompleteElicitationNotification {
pub elicitation_id: ElicitationId,
pub meta: Option<Meta>,
}Available on crate feature
unstable_elicitation only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Notification sent by the agent when a URL-based elicitation is complete.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.elicitation_id: ElicitationIdThe ID of the elicitation that completed.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl CompleteElicitationNotification
impl CompleteElicitationNotification
pub fn new(elicitation_id: impl Into<ElicitationId>) -> Self
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility