#[non_exhaustive]pub struct ContentChunk {
pub content: ContentBlock,
pub message_id: Option<MessageId>,
pub meta: Option<Meta>,
}Expand description
A streamed item of content
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.content: ContentBlockA single item of content
message_id: Option<MessageId>A unique identifier for the message this chunk belongs to.
All chunks belonging to the same message share the same messageId.
A change in messageId indicates a new message has started.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ContentChunk
impl ContentChunk
pub fn new(content: ContentBlock) -> Self
Sourcepub fn message_id(self, message_id: impl IntoOption<MessageId>) -> Self
pub fn message_id(self, message_id: impl IntoOption<MessageId>) -> Self
A unique identifier for the message this chunk belongs to.
All chunks belonging to the same message share the same messageId.
A change in messageId indicates a new message has started.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility