#[non_exhaustive]pub struct DidFocusDocumentNotification {
pub session_id: SessionId,
pub uri: String,
pub version: i64,
pub position: Position,
pub visible_range: Range,
pub meta: Option<Meta>,
}Available on crate feature
unstable_nes only.Expand description
Notification sent when a file becomes the active editor tab.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdThe session ID for this notification.
uri: StringThe URI of the focused document.
version: i64The version number of the document.
position: PositionThe current cursor position.
visible_range: RangeThe portion of the file currently visible in the editor viewport.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl DidFocusDocumentNotification
impl DidFocusDocumentNotification
pub fn new( session_id: impl Into<SessionId>, uri: impl Into<String>, version: i64, position: Position, visible_range: Range, ) -> Self
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility