#[non_exhaustive]pub struct DidOpenDocumentNotification {
pub session_id: SessionId,
pub uri: String,
pub language_id: String,
pub version: i64,
pub text: String,
pub meta: Option<Meta>,
}Available on crate feature
unstable_nes only.Expand description
Notification sent when a file is opened in the editor.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdThe session ID for this notification.
uri: StringThe URI of the opened document.
language_id: StringThe language identifier of the document (e.g., “rust”, “python”).
version: i64The version number of the document.
text: StringThe full text content of the document.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl DidOpenDocumentNotification
impl DidOpenDocumentNotification
pub fn new( session_id: impl Into<SessionId>, uri: impl Into<String>, language_id: impl Into<String>, version: i64, text: impl Into<String>, ) -> Self
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility