#[non_exhaustive]pub struct FileSystemCapabilities {
pub read_text_file: bool,
pub write_text_file: bool,
pub meta: Option<Meta>,
}Expand description
File system capabilities that a client may support.
See protocol docs: FileSystem
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.read_text_file: boolWhether the Client supports fs/read_text_file requests.
write_text_file: boolWhether the Client supports fs/write_text_file requests.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl FileSystemCapabilities
impl FileSystemCapabilities
pub fn new() -> Self
Sourcepub fn read_text_file(self, read_text_file: bool) -> Self
pub fn read_text_file(self, read_text_file: bool) -> Self
Whether the Client supports fs/read_text_file requests.
Sourcepub fn write_text_file(self, write_text_file: bool) -> Self
pub fn write_text_file(self, write_text_file: bool) -> Self
Whether the Client supports fs/write_text_file requests.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility