#[non_exhaustive]pub struct ForkSessionRequest {
pub session_id: SessionId,
pub cwd: PathBuf,
pub additional_directories: Vec<PathBuf>,
pub mcp_servers: Vec<McpServer>,
pub meta: Option<Meta>,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Request parameters for forking an existing session.
Creates a new session based on the context of an existing one, allowing operations like generating summaries without affecting the original session’s history.
Only available if the Agent supports the session.fork capability.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdThe ID of the session to fork.
cwd: PathBufThe working directory for this session.
additional_directories: Vec<PathBuf>Additional workspace roots to activate for this session. Each path must be absolute.
When omitted or empty, no additional roots are activated. When non-empty, this is the complete resulting additional-root list for the forked session.
mcp_servers: Vec<McpServer>List of MCP servers to connect to for this session.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ForkSessionRequest
impl ForkSessionRequest
pub fn new(session_id: impl Into<SessionId>, cwd: impl Into<PathBuf>) -> Self
unstable_session_fork only.Sourcepub fn additional_directories(
self,
additional_directories: Vec<PathBuf>,
) -> Self
Available on crate feature unstable_session_fork only.
pub fn additional_directories( self, additional_directories: Vec<PathBuf>, ) -> Self
unstable_session_fork only.Additional workspace roots to activate for this session. Each path must be absolute.
Sourcepub fn mcp_servers(self, mcp_servers: Vec<McpServer>) -> Self
Available on crate feature unstable_session_fork only.
pub fn mcp_servers(self, mcp_servers: Vec<McpServer>) -> Self
unstable_session_fork only.List of MCP servers to connect to for this session.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
Available on crate feature unstable_session_fork only.
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
unstable_session_fork only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility