#[non_exhaustive]pub struct GeneralMethodNames {
pub cancel_request: &'static str,
}Available on crate feature
unstable_cancel_request only.Expand description
Names of all methods that agents handle.
Provides a centralized definition of method names used in the protocol.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cancel_request: &'static strTrait Implementations
Sourceimpl Clone for GeneralMethodNames
impl Clone for GeneralMethodNames
Sourcefn clone(&self) -> GeneralMethodNames
fn clone(&self) -> GeneralMethodNames
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GeneralMethodNames
impl Debug for GeneralMethodNames
Sourceimpl Deserialize<'static> for GeneralMethodNames
impl Deserialize<'static> for GeneralMethodNames
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'static>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'static>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GeneralMethodNames
Sourceimpl PartialEq for GeneralMethodNames
impl PartialEq for GeneralMethodNames
Sourcefn eq(&self, other: &GeneralMethodNames) -> bool
fn eq(&self, other: &GeneralMethodNames) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GeneralMethodNames
impl Serialize for GeneralMethodNames
impl StructuralPartialEq for GeneralMethodNames