#[non_exhaustive]pub struct ListProvidersResponse {
pub providers: Vec<ProviderInfo>,
pub meta: Option<Meta>,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Response to providers/list.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.providers: Vec<ProviderInfo>Configurable providers with current routing info suitable for UI display.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ListProvidersResponse
impl ListProvidersResponse
pub fn new(providers: Vec<ProviderInfo>) -> Self
Available on crate feature
unstable_llm_providers only.Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
Available on crate feature unstable_llm_providers only.
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
unstable_llm_providers only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility