#[non_exhaustive]pub struct ListSessionsRequest {
pub cwd: Option<PathBuf>,
pub cursor: Option<String>,
pub meta: Option<Meta>,
}Expand description
Request parameters for listing existing sessions.
Only available if the Agent supports the sessionCapabilities.list capability.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cwd: Option<PathBuf>Filter sessions by working directory. Must be an absolute path.
cursor: Option<String>Opaque cursor token from a previous response’s nextCursor field for cursor-based pagination
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ListSessionsRequest
impl ListSessionsRequest
pub fn new() -> Self
Sourcepub fn cwd(self, cwd: impl IntoOption<PathBuf>) -> Self
pub fn cwd(self, cwd: impl IntoOption<PathBuf>) -> Self
Filter sessions by working directory. Must be an absolute path.
Sourcepub fn cursor(self, cursor: impl IntoOption<String>) -> Self
pub fn cursor(self, cursor: impl IntoOption<String>) -> Self
Opaque cursor token from a previous response’s nextCursor field for cursor-based pagination
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility