#[non_exhaustive]pub struct ListSessionsResponse {
pub sessions: Vec<SessionInfo>,
pub next_cursor: Option<String>,
pub meta: Option<Meta>,
}Expand description
Response from listing sessions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.sessions: Vec<SessionInfo>Array of session information objects
next_cursor: Option<String>Opaque cursor token. If present, pass this in the next request’s cursor parameter to fetch the next page. If absent, there are no more results.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ListSessionsResponse
impl ListSessionsResponse
pub fn new(sessions: Vec<SessionInfo>) -> Self
pub fn next_cursor(self, next_cursor: impl IntoOption<String>) -> Self
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility