#[non_exhaustive]pub struct NesCapabilities {
pub events: Option<NesEventCapabilities>,
pub context: Option<NesContextCapabilities>,
pub meta: Option<Meta>,
}Available on crate feature
unstable_nes only.Expand description
NES capabilities advertised by the agent during initialization.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.events: Option<NesEventCapabilities>Events the agent wants to receive.
context: Option<NesContextCapabilities>Context the agent wants attached to each suggestion request.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl NesCapabilities
impl NesCapabilities
pub fn new() -> Self
pub fn events(self, events: impl IntoOption<NesEventCapabilities>) -> Self
pub fn context(self, context: impl IntoOption<NesContextCapabilities>) -> Self
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility