NesContextCapabilities

Struct NesContextCapabilities 

#[non_exhaustive]
pub struct NesContextCapabilities { pub recent_files: Option<NesRecentFilesCapabilities>, pub related_snippets: Option<NesRelatedSnippetsCapabilities>, pub edit_history: Option<NesEditHistoryCapabilities>, pub user_actions: Option<NesUserActionsCapabilities>, pub open_files: Option<NesOpenFilesCapabilities>, pub diagnostics: Option<NesDiagnosticsCapabilities>, pub meta: Option<Meta>, }
Available on crate feature unstable_nes only.
Context capabilities the agent wants attached to each suggestion request.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
recent_files: Option<NesRecentFilesCapabilities>

Whether the agent wants recent files context.

related_snippets: Option<NesRelatedSnippetsCapabilities>

Whether the agent wants related snippets context.

edit_history: Option<NesEditHistoryCapabilities>

Whether the agent wants edit history context.

user_actions: Option<NesUserActionsCapabilities>

Whether the agent wants user actions context.

open_files: Option<NesOpenFilesCapabilities>

Whether the agent wants open files context.

diagnostics: Option<NesDiagnosticsCapabilities>

Whether the agent wants diagnostics context.

meta: Option<Meta>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl NesContextCapabilities

pub fn new() -> Self

pub fn recent_files( self, recent_files: impl IntoOption<NesRecentFilesCapabilities>, ) -> Self

pub fn related_snippets( self, related_snippets: impl IntoOption<NesRelatedSnippetsCapabilities>, ) -> Self

pub fn edit_history( self, edit_history: impl IntoOption<NesEditHistoryCapabilities>, ) -> Self

pub fn user_actions( self, user_actions: impl IntoOption<NesUserActionsCapabilities>, ) -> Self

pub fn open_files( self, open_files: impl IntoOption<NesOpenFilesCapabilities>, ) -> Self

pub fn diagnostics( self, diagnostics: impl IntoOption<NesDiagnosticsCapabilities>, ) -> Self

pub fn meta(self, meta: impl IntoOption<Meta>) -> Self

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility