#[non_exhaustive]pub struct NesRecentFilesCapabilities {
pub max_count: Option<u32>,
pub meta: Option<Meta>,
}Available on crate feature
unstable_nes only.Expand description
Capabilities for recent files context.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_count: Option<u32>Maximum number of recent files the agent can use.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations