#[non_exhaustive]pub struct NesSearchAndReplaceSuggestion {
pub id: String,
pub uri: String,
pub search: String,
pub replace: String,
pub is_regex: Option<bool>,
pub meta: Option<Meta>,
}unstable_nes only.Expand description
A search-and-replace suggestion.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringUnique identifier for accept/reject tracking.
uri: StringThe file URI to search within.
search: StringThe text or pattern to find.
replace: StringThe replacement text.
is_regex: Option<bool>Whether search is a regular expression. Defaults to false.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl NesSearchAndReplaceSuggestion
impl NesSearchAndReplaceSuggestion
Sourcepub fn new(
id: impl Into<String>,
uri: impl Into<String>,
search: impl Into<String>,
replace: impl Into<String>,
) -> Self
pub fn new( id: impl Into<String>, uri: impl Into<String>, search: impl Into<String>, replace: impl Into<String>, ) -> Self
Builds NesSearchAndReplaceSuggestion with the required fields set; optional fields start unset or empty.
Sourcepub fn is_regex(self, is_regex: impl IntoOption<bool>) -> Self
pub fn is_regex(self, is_regex: impl IntoOption<bool>) -> Self
Sets or clears the optional isRegex field.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility