#[non_exhaustive]pub struct NesTextEdit {
pub range: Range,
pub new_text: String,
pub meta: Option<Meta>,
}Available on crate feature
unstable_nes only.Expand description
A text edit within a suggestion.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.range: RangeThe range to replace.
new_text: StringThe replacement text.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl NesTextEdit
impl NesTextEdit
Sourcepub fn new(range: Range, new_text: impl Into<String>) -> Self
pub fn new(range: Range, new_text: impl Into<String>) -> Self
Builds NesTextEdit with the required fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility