PlanItems

Struct PlanItems 

#[non_exhaustive]
pub struct PlanItems { pub id: PlanId, pub entries: Vec<PlanEntry>, pub meta: Option<Meta>, }
UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

A plan represented as structured entries.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: PlanId

The plan ID to update.

entries: Vec<PlanEntry>

The list of tasks to be accomplished.

When updating an item-based plan, the agent must send a complete list of all entries with their current status. The client replaces that plan with each update.

meta: Option<Meta>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl PlanItems

pub fn new(id: impl Into<PlanId>, entries: Vec<PlanEntry>) -> Self

Available on crate feature unstable_plan_operations only.
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self

Available on crate feature unstable_plan_operations only.

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility