#[non_exhaustive]pub struct RejectNesNotification {
pub session_id: SessionId,
pub id: String,
pub reason: Option<NesRejectReason>,
pub meta: Option<Meta>,
}Available on crate feature
unstable_nes only.Expand description
Notification sent when a suggestion is rejected.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdThe session ID for this notification.
id: StringThe ID of the rejected suggestion.
reason: Option<NesRejectReason>The reason for rejection.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl RejectNesNotification
impl RejectNesNotification
pub fn new(session_id: impl Into<SessionId>, id: impl Into<String>) -> Self
pub fn reason(self, reason: impl IntoOption<NesRejectReason>) -> Self
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility