#[non_exhaustive]pub struct ResourceLink {
pub annotations: Option<Annotations>,
pub description: Option<String>,
pub mime_type: Option<String>,
pub name: String,
pub size: Option<i64>,
pub title: Option<String>,
pub uri: String,
pub meta: Option<Meta>,
}Expand description
A resource that the server is capable of reading, included in a prompt or tool call result.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.annotations: Option<Annotations>Optional annotations that help clients decide how to display or route this content.
description: Option<String>Optional human-readable details shown with this protocol object.
mime_type: Option<String>MIME type describing the encoded media payload.
name: StringHuman-readable name shown for this protocol object.
size: Option<i64>Optional size of the linked resource in bytes, if known.
title: Option<String>Optional display title for end-user UI.
uri: StringURI associated with this resource or media payload.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ResourceLink
impl ResourceLink
Sourcepub fn new(name: impl Into<String>, uri: impl Into<String>) -> Self
pub fn new(name: impl Into<String>, uri: impl Into<String>) -> Self
Builds ResourceLink with its required content payload; optional annotations and metadata start unset.
Sourcepub fn annotations(self, annotations: impl IntoOption<Annotations>) -> Self
pub fn annotations(self, annotations: impl IntoOption<Annotations>) -> Self
Sets or clears the optional annotations field.
Sourcepub fn description(self, description: impl IntoOption<String>) -> Self
pub fn description(self, description: impl IntoOption<String>) -> Self
Sets or clears the optional description field.
Sourcepub fn mime_type(self, mime_type: impl IntoOption<String>) -> Self
pub fn mime_type(self, mime_type: impl IntoOption<String>) -> Self
Sets or clears the optional mimeType field.
Sourcepub fn size(self, size: impl IntoOption<i64>) -> Self
pub fn size(self, size: impl IntoOption<i64>) -> Self
Sets or clears the optional size field.
Sourcepub fn title(self, title: impl IntoOption<String>) -> Self
pub fn title(self, title: impl IntoOption<String>) -> Self
Sets or clears the optional title field.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility