#[non_exhaustive]pub struct ResumeSessionRequest {
pub session_id: SessionId,
pub cwd: PathBuf,
pub mcp_servers: Vec<McpServer>,
pub meta: Option<Meta>,
}Expand description
Request parameters for resuming an existing session.
Resumes an existing session without returning previous messages (unlike session/load).
This is useful for agents that can resume sessions but don’t implement full session loading.
Only available if the Agent supports the sessionCapabilities.resume capability.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdThe ID of the session to resume.
cwd: PathBufThe working directory for this session.
mcp_servers: Vec<McpServer>List of MCP servers to connect to for this session.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ResumeSessionRequest
impl ResumeSessionRequest
pub fn new(session_id: impl Into<SessionId>, cwd: impl Into<PathBuf>) -> Self
Sourcepub fn mcp_servers(self, mcp_servers: Vec<McpServer>) -> Self
pub fn mcp_servers(self, mcp_servers: Vec<McpServer>) -> Self
List of MCP servers to connect to for this session.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility