ResumeSessionResponse

Struct ResumeSessionResponse 

#[non_exhaustive]
pub struct ResumeSessionResponse { pub modes: Option<SessionModeState>, pub config_options: Option<Vec<SessionConfigOption>>, pub meta: Option<Meta>, }
Response from resuming an existing session.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
modes: Option<SessionModeState>

Initial mode state if supported by the Agent

See protocol docs: Session Modes

config_options: Option<Vec<SessionConfigOption>>

Initial session configuration options if supported by the Agent.

meta: Option<Meta>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl ResumeSessionResponse

pub fn new() -> Self

pub fn modes(self, modes: impl IntoOption<SessionModeState>) -> Self

Initial mode state if supported by the Agent

See protocol docs: Session Modes

pub fn config_options( self, config_options: impl IntoOption<Vec<SessionConfigOption>>, ) -> Self

Initial session configuration options if supported by the Agent.

pub fn meta(self, meta: impl IntoOption<Meta>) -> Self

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility