#[non_exhaustive]pub struct SetProviderRequest {
pub id: String,
pub api_type: LlmProtocol,
pub base_url: String,
pub headers: HashMap<String, String>,
pub meta: Option<Meta>,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Request parameters for providers/set.
Replaces the full configuration for one provider id.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringProvider id to configure.
api_type: LlmProtocolProtocol type for this provider.
base_url: StringBase URL for requests sent through this provider.
headers: HashMap<String, String>Full headers map for this provider. May include authorization, routing, or other integration-specific headers.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl SetProviderRequest
impl SetProviderRequest
pub fn new( id: impl Into<String>, api_type: LlmProtocol, base_url: impl Into<String>, ) -> Self
unstable_llm_providers only.Sourcepub fn headers(self, headers: HashMap<String, String>) -> Self
Available on crate feature unstable_llm_providers only.
pub fn headers(self, headers: HashMap<String, String>) -> Self
unstable_llm_providers only.Full headers map for this provider. May include authorization, routing, or other integration-specific headers.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
Available on crate feature unstable_llm_providers only.
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
unstable_llm_providers only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility