StringPropertySchema

Struct StringPropertySchema 

#[non_exhaustive]
pub struct StringPropertySchema { pub title: Option<String>, pub description: Option<String>, pub min_length: Option<u32>, pub max_length: Option<u32>, pub pattern: Option<String>, pub format: Option<StringFormat>, pub default: Option<String>, pub enum_values: Option<Vec<String>>, pub one_of: Option<Vec<EnumOption>>, pub meta: Option<Meta>, }
Available on crate feature unstable_elicitation only.
Schema for string properties in an elicitation form.

When enum or oneOf is set, this represents a single-select enum with "type": "string".

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
title: Option<String>

Optional title for the property.

description: Option<String>

Human-readable description.

min_length: Option<u32>

Minimum string length.

max_length: Option<u32>

Maximum string length.

pattern: Option<String>

Pattern the string must match.

format: Option<StringFormat>

String format.

default: Option<String>

Default value.

enum_values: Option<Vec<String>>

Enum values for untitled single-select enums.

one_of: Option<Vec<EnumOption>>

Titled enum options for titled single-select enums.

meta: Option<Meta>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl StringPropertySchema

pub fn new() -> Self

Create a new string property schema.

pub fn email() -> Self

Create an email string property schema.

pub fn uri() -> Self

Create a URI string property schema.

pub fn date() -> Self

Create a date string property schema.

pub fn date_time() -> Self

Create a date-time string property schema.

pub fn title(self, title: impl IntoOption<String>) -> Self

Optional title for the property.

pub fn description(self, description: impl IntoOption<String>) -> Self

Human-readable description.

pub fn min_length(self, min_length: impl IntoOption<u32>) -> Self

Minimum string length.

pub fn max_length(self, max_length: impl IntoOption<u32>) -> Self

Maximum string length.

pub fn pattern(self, pattern: impl IntoOption<String>) -> Self

Pattern the string must match.

pub fn format(self, format: impl IntoOption<StringFormat>) -> Self

String format.

pub fn default_value(self, default: impl IntoOption<String>) -> Self

Default value.

pub fn enum_values(self, enum_values: impl IntoOption<Vec<String>>) -> Self

Enum values for untitled single-select enums.

pub fn one_of(self, one_of: impl IntoOption<Vec<EnumOption>>) -> Self

Titled enum options for titled single-select enums.

pub fn meta(self, meta: impl IntoOption<Meta>) -> Self

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility