SuggestNesRequest

Struct SuggestNesRequest 

#[non_exhaustive]
pub struct SuggestNesRequest { pub session_id: SessionId, pub uri: String, pub version: i64, pub position: Position, pub selection: Option<Range>, pub trigger_kind: NesTriggerKind, pub context: Option<NesSuggestContext>, pub meta: Option<Meta>, }
Available on crate feature unstable_nes only.
Request for a code suggestion.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
session_id: SessionId

The session ID for this request.

uri: String

The URI of the document to suggest for.

version: i64

The version number of the document.

position: Position

The current cursor position.

selection: Option<Range>

The current text selection range, if any.

trigger_kind: NesTriggerKind

What triggered this suggestion request.

context: Option<NesSuggestContext>

Context for the suggestion, included based on agent capabilities.

meta: Option<Meta>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl SuggestNesRequest

pub fn new( session_id: impl Into<SessionId>, uri: impl Into<String>, version: i64, position: Position, trigger_kind: NesTriggerKind, ) -> Self

pub fn selection(self, selection: impl IntoOption<Range>) -> Self

pub fn context(self, context: impl IntoOption<NesSuggestContext>) -> Self

pub fn meta(self, meta: impl IntoOption<Meta>) -> Self

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility