#[non_exhaustive]pub struct SuggestNesResponse {
pub suggestions: Vec<NesSuggestion>,
pub meta: Option<Meta>,
}Available on crate feature
unstable_nes only.Expand description
Response to nes/suggest.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.suggestions: Vec<NesSuggestion>The list of suggestions.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl SuggestNesResponse
impl SuggestNesResponse
pub fn new(suggestions: Vec<NesSuggestion>) -> Self
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility