#[non_exhaustive]pub struct TextDocumentContentChangeEvent {
pub range: Option<Range>,
pub text: String,
}Available on crate feature
unstable_nes only.Expand description
A content change event for a document.
When range is None, text is the full content of the document.
When range is Some, text replaces the given range.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.range: Option<Range>The range of the document that changed. If None, the entire content is replaced.
text: StringThe new text for the range, or the full document content if range is None.
Implementations