#[non_exhaustive]pub struct UrlElicitationRequiredData {
pub elicitations: Vec<UrlElicitationRequiredItem>,
}Available on crate feature
unstable_elicitation only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Data payload for the UrlElicitationRequired error, describing the URL elicitations
the user must complete.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.elicitations: Vec<UrlElicitationRequiredItem>The URL elicitations the user must complete.
Implementations
Sourceimpl UrlElicitationRequiredData
impl UrlElicitationRequiredData
pub fn new(elicitations: Vec<UrlElicitationRequiredItem>) -> Self