#[non_exhaustive]pub struct UsageUpdate {
pub used: u64,
pub size: u64,
pub cost: Option<Cost>,
pub meta: Option<Meta>,
}Expand description
Context window and cost update for a session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.used: u64Tokens currently in context.
size: u64Total context window size in tokens.
cost: Option<Cost>Cumulative session cost (optional).
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl UsageUpdate
impl UsageUpdate
pub fn new(used: u64, size: u64) -> Self
Sourcepub fn cost(self, cost: impl IntoOption<Cost>) -> Self
pub fn cost(self, cost: impl IntoOption<Cost>) -> Self
Cumulative session cost (optional).
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility