IntoMaybeUndefined

Trait IntoMaybeUndefined 

pub trait IntoMaybeUndefined<T> {
    // Required method
    fn into_maybe_undefined(self) -> MaybeUndefined<T>;
}
Utility trait for builder methods for optional values. This allows the caller to either pass in the value itself without wrapping it in Some, or to just pass in an Option if that is what they have, or set it back to undefined.

Required Methods

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoMaybeUndefined<Value> for &str

Source

impl IntoMaybeUndefined<Value> for Cow<'_, str>

Source

impl IntoMaybeUndefined<Value> for String

Source

impl IntoMaybeUndefined<String> for &str

Source

impl IntoMaybeUndefined<String> for &String

Source

impl IntoMaybeUndefined<String> for &mut str

Source

impl IntoMaybeUndefined<String> for Cow<'_, str>

Source

impl IntoMaybeUndefined<String> for Box<str>

Source

impl IntoMaybeUndefined<String> for Arc<str>

Source

impl IntoMaybeUndefined<PathBuf> for Cow<'_, Path>

Source

impl IntoMaybeUndefined<PathBuf> for Box<Path>

Source

impl<T> IntoMaybeUndefined<T> for Option<T>

Source

impl<T: ?Sized + AsRef<OsStr>> IntoMaybeUndefined<PathBuf> for &T

Implementors