#[non_exhaustive]pub enum AuthMethod {
Terminal(AuthMethodTerminal),
Agent(AuthMethodAgent),
}Expand description
Describes an available authentication method.
The type field acts as the discriminator in the serialized JSON form.
When no type is present, the method is treated as agent.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Terminal(AuthMethodTerminal)
Client runs the configured agent program as a separate interactive
process, without passing this method to authenticate.
Agent(AuthMethodAgent)
Agent handles authentication itself through authenticate.
This is the default when no type is specified.
Implementations
Sourceimpl AuthMethod
impl AuthMethod
Sourcepub fn id(&self) -> &AuthMethodId
pub fn id(&self) -> &AuthMethodId
The unique identifier for this authentication method.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Optional description providing more details about this authentication method.
Sourcepub fn meta(&self) -> Option<&Meta>
pub fn meta(&self) -> Option<&Meta>
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility