#[non_exhaustive]pub enum CompactionStatus {
InProgress,
Completed,
Failed,
Cancelled,
Other(String),
}Available on crate feature
unstable_session_compaction only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Lifecycle state of a context compaction.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InProgress
Compaction has started and has not finished.
Completed
Compaction finished successfully.
Failed
Compaction finished unsuccessfully.
Cancelled
Compaction was cancelled before it finished.
Other(String)
Custom or future compaction status.
Values beginning with _ are reserved for implementation-specific
extensions. Other unknown values are reserved for future ACP statuses.