#[non_exhaustive]pub enum NoticeSeverity {
Info,
Warning,
Error,
Other(String),
}Available on crate feature
unstable_session_notices only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Severity hint for a session notice.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Info
Informational notice.
Warning
Warning notice.
Error
Error notice.
Other(String)
Custom or future notice severity.
Values beginning with _ are reserved for implementation-specific
extensions. Other unknown values are reserved for future ACP severities.