#[non_exhaustive]pub enum StopReason {
EndTurn,
MaxTokens,
MaxTurnRequests,
Refusal,
Cancelled,
}Expand description
Reasons why an agent stops processing a prompt turn.
See protocol docs: Stop Reasons
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EndTurn
The turn ended successfully.
MaxTokens
The turn ended because the agent reached the maximum number of tokens.
MaxTurnRequests
The turn ended because the agent reached the maximum number of allowed agent requests between user turns.
Refusal
The turn ended because the agent refused to continue. The user prompt and everything that comes after it won’t be included in the next prompt, so this should be reflected in the UI.
Cancelled
The turn was cancelled by the client via session/cancel.
This stop reason MUST be returned when the client sends a session/cancel
notification, even if the cancellation causes exceptions in underlying operations.
Agents should catch these exceptions and return this semantically meaningful
response to confirm successful cancellation.