#[non_exhaustive]pub struct AgentAuthCapabilities {
pub logout: Option<LogoutCapabilities>,
pub meta: Option<Meta>,
}Expand description
Authentication-related capabilities supported by the agent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.logout: Option<LogoutCapabilities>Whether the agent supports the logout method.
By supplying {} it means that the agent supports the logout method.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl AgentAuthCapabilities
impl AgentAuthCapabilities
Sourcepub fn new() -> Self
pub fn new() -> Self
Builds an empty AgentAuthCapabilities; use builder methods to advertise supported sub-capabilities.
Sourcepub fn logout(self, logout: impl IntoOption<LogoutCapabilities>) -> Self
pub fn logout(self, logout: impl IntoOption<LogoutCapabilities>) -> Self
Whether the agent supports the logout method.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility