#[non_exhaustive]pub struct AudioContent {
pub annotations: Option<Annotations>,
pub data: String,
pub mime_type: String,
pub meta: Option<Meta>,
}Expand description
Audio provided to or from an LLM.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.annotations: Option<Annotations>Optional annotations that help clients decide how to display or route this content.
data: StringBase64-encoded media payload.
mime_type: StringMIME type describing the encoded media payload.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl AudioContent
impl AudioContent
Sourcepub fn new(data: impl Into<String>, mime_type: impl Into<String>) -> Self
pub fn new(data: impl Into<String>, mime_type: impl Into<String>) -> Self
Builds AudioContent with its required content payload; optional annotations and metadata start unset.
Sourcepub fn annotations(self, annotations: impl IntoOption<Annotations>) -> Self
pub fn annotations(self, annotations: impl IntoOption<Annotations>) -> Self
Sets or clears the optional annotations field.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility