#[non_exhaustive]pub struct AuthCapabilities {
pub terminal: bool,
pub meta: Option<Meta>,
}Expand description
Authentication capabilities supported by the client.
Advertised during initialization to inform the agent which authentication method types the client can handle. This governs opt-in types that require additional client-side support.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.terminal: boolWhether the client supports terminal authentication methods.
The client should set this to true only when it can reproduce the
configured agent invocation in an interactive terminal. When true, the
agent may include terminal entries in its authentication methods.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl AuthCapabilities
impl AuthCapabilities
Sourcepub fn new() -> Self
pub fn new() -> Self
Builds an empty AuthCapabilities; use builder methods to advertise supported sub-capabilities.
Sourcepub fn terminal(self, terminal: bool) -> Self
pub fn terminal(self, terminal: bool) -> Self
Whether the client supports terminal authentication methods.
The client should set this to true only when it can reproduce the
configured agent invocation in an interactive terminal. When true, the
agent may include AuthMethod::Terminal entries in its authentication
methods.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility