#[non_exhaustive]pub struct CancelRequestNotification {
pub request_id: RequestId,
pub meta: Option<Meta>,
}unstable_cancel_request only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Notification to cancel an ongoing request.
See protocol docs: Cancellation
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.request_id: RequestIdThe ID of the request to cancel.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl CancelRequestNotification
impl CancelRequestNotification
Sourcepub fn new(request_id: impl Into<RequestId>) -> Self
pub fn new(request_id: impl Into<RequestId>) -> Self
Builds CancelRequestNotification with the required notification fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility