#[non_exhaustive]pub struct CompactionCapabilities {}Available on crate feature
unstable_session_compaction only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Client support for ID-addressed context compaction updates.
Implementations