Cost

Struct Cost 

#[non_exhaustive]
pub struct Cost { pub amount: f64, pub currency: String, pub meta: Option<Meta>, }
Cost information for a session.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
amount: f64

Total cumulative cost for session.

currency: String

ISO 4217 currency code (e.g., “USD”, “EUR”).

meta: Option<Meta>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl Cost

pub fn new(amount: f64, currency: impl Into<String>) -> Self

Builds Cost with the required fields set; optional fields start unset or empty.

pub fn meta(self, meta: impl IntoOption<Meta>) -> Self

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility