#[non_exhaustive]pub struct Diff {
pub path: PathBuf,
pub old_text: Option<String>,
pub new_text: String,
pub meta: Option<Meta>,
}Expand description
A diff representing file modifications.
Shows changes to files in a format suitable for display in the client UI.
See protocol docs: Content
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.path: PathBufThe file path being modified.
old_text: Option<String>The original content (None for new files).
new_text: StringThe new content after modification.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl Diff
impl Diff
Sourcepub fn new(path: impl Into<PathBuf>, new_text: impl Into<String>) -> Self
pub fn new(path: impl Into<PathBuf>, new_text: impl Into<String>) -> Self
Builds Diff with the required fields set; optional fields start unset or empty.
Sourcepub fn old_text(self, old_text: impl IntoOption<String>) -> Self
pub fn old_text(self, old_text: impl IntoOption<String>) -> Self
The original content (None for new files).
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility