#[non_exhaustive]pub struct EnumOption {
pub value: String,
pub title: String,
pub description: Option<String>,
pub meta: Option<Meta>,
}Expand description
A titled enum option with a const value, human-readable title, and optional description.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.value: StringThe constant value for this option.
title: StringHuman-readable title for this option.
description: Option<String>Human-readable description.
Optional. Omitted and null are equivalent and mean no description is provided.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
Optional. Omitted and null are equivalent and mean no metadata.
See protocol docs: Extensibility
Implementations
Sourceimpl EnumOption
impl EnumOption
Sourcepub fn new(value: impl Into<String>, title: impl Into<String>) -> Self
pub fn new(value: impl Into<String>, title: impl Into<String>) -> Self
Create a new enum option.
Sourcepub fn description(self, description: impl IntoOption<String>) -> Self
pub fn description(self, description: impl IntoOption<String>) -> Self
Human-readable description.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
Optional. Omitted and null are equivalent and mean no metadata.
See protocol docs: Extensibility