#[non_exhaustive]pub struct ErrorStopReason {
pub error: Option<Box<Error>>,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Details of a failure that ended a child’s foreground work.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.error: Option<Box<Error>>The failure, as a JSON-RPC error object.
Optional. Omitted or null both mean the agent is not reporting failure details.
Agents SHOULD include it.
Implementations
Sourceimpl ErrorStopReason
impl ErrorStopReason
Sourcepub fn new() -> Self
Available on crate feature unstable_subagents only.
pub fn new() -> Self
unstable_subagents only.Builds ErrorStopReason with the required fields set; optional fields start unset or empty.
Sourcepub fn error(self, error: impl IntoOption<Error>) -> Self
Available on crate feature unstable_subagents only.
pub fn error(self, error: impl IntoOption<Error>) -> Self
unstable_subagents only.The failure, as a JSON-RPC error object.