#[non_exhaustive]pub struct McpServerStdio {
pub name: String,
pub command: PathBuf,
pub args: Vec<String>,
pub env: Vec<EnvVariable>,
pub meta: Option<Meta>,
}Expand description
Stdio transport configuration for MCP.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringHuman-readable name identifying this MCP server.
command: PathBufPath to the MCP server executable.
args: Vec<String>Command-line arguments to pass to the MCP server.
env: Vec<EnvVariable>Environment variables to set when launching the MCP server.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl McpServerStdio
impl McpServerStdio
Sourcepub fn new(name: impl Into<String>, command: impl Into<PathBuf>) -> Self
pub fn new(name: impl Into<String>, command: impl Into<PathBuf>) -> Self
Builds McpServerStdio with the required fields set; optional fields start unset or empty.
Sourcepub fn env(self, env: Vec<EnvVariable>) -> Self
pub fn env(self, env: Vec<EnvVariable>) -> Self
Environment variables to set when launching the MCP server.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility