#[non_exhaustive]pub struct MessageMcpNotification {
pub server_id: McpServerAcpId,
pub request_id: McpRequestId,
pub method: String,
pub params: Option<Map<String, Value>>,
pub meta: Option<Meta>,
}unstable_mcp_over_acp only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Notification parameters for mcp/message.
Sent by the provider to the consumer for an active request (including
subscription acknowledgements and updates); the outer envelope has no id.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.server_id: McpServerAcpIdThe declared ACP MCP server handling the associated request.
request_id: McpRequestIdThe identifier of the active inner MCP request.
method: StringThe inner MCP method name.
params: Option<Map<String, Value>>Optional inner MCP params.
If omitted or set to null, the inner MCP message has no params.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl MessageMcpNotification
impl MessageMcpNotification
Sourcepub fn new(
server_id: impl Into<McpServerAcpId>,
request_id: impl Into<McpRequestId>,
method: impl Into<String>,
) -> Self
pub fn new( server_id: impl Into<McpServerAcpId>, request_id: impl Into<McpRequestId>, method: impl Into<String>, ) -> Self
Builds MessageMcpNotification with the required notification fields set; optional fields start unset or empty.
Sourcepub fn params(self, params: impl IntoOption<Map<String, Value>>) -> Self
pub fn params(self, params: impl IntoOption<Map<String, Value>>) -> Self
Optional inner MCP params.
If omitted or set to null, the inner MCP message has no params.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility