#[non_exhaustive]pub struct NesExcerpt {
pub start_line: u32,
pub end_line: u32,
pub text: String,
pub meta: Option<Meta>,
}Available on crate feature
unstable_nes only.Expand description
A code excerpt from a file.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_line: u32The start line of the excerpt (zero-based).
end_line: u32The end line of the excerpt (zero-based).
text: StringThe text content of the excerpt.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl NesExcerpt
impl NesExcerpt
Sourcepub fn new(start_line: u32, end_line: u32, text: impl Into<String>) -> Self
pub fn new(start_line: u32, end_line: u32, text: impl Into<String>) -> Self
Builds NesExcerpt with the required fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility