#[non_exhaustive]pub struct NesOpenFile {
pub uri: String,
pub language_id: String,
pub visible_range: Option<Range>,
pub last_focused_ms: Option<u64>,
pub meta: Option<Meta>,
}unstable_nes only.Expand description
An open file in the editor.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uri: StringThe URI of the file.
language_id: StringThe language identifier.
visible_range: Option<Range>The visible range in the editor, if any.
last_focused_ms: Option<u64>Timestamp in milliseconds since epoch of when the file was last focused.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl NesOpenFile
impl NesOpenFile
Sourcepub fn new(uri: impl Into<String>, language_id: impl Into<String>) -> Self
pub fn new(uri: impl Into<String>, language_id: impl Into<String>) -> Self
Builds NesOpenFile with the required fields set; optional fields start unset or empty.
Sourcepub fn visible_range(self, visible_range: impl IntoOption<Range>) -> Self
pub fn visible_range(self, visible_range: impl IntoOption<Range>) -> Self
Sets or clears the optional visibleRange field.
Sourcepub fn last_focused_ms(self, last_focused_ms: impl IntoOption<u64>) -> Self
pub fn last_focused_ms(self, last_focused_ms: impl IntoOption<u64>) -> Self
Sets or clears the optional lastFocusedMs field.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility