#[non_exhaustive]pub struct NewSessionResponse {
pub session_id: SessionId,
pub modes: Option<SessionModeState>,
pub config_options: Option<Vec<SessionConfigOption>>,
pub meta: Option<Meta>,
}Expand description
Response from creating a new session.
See protocol docs: Creating a Session
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdUnique identifier for the created session.
Used in all subsequent requests for this conversation.
modes: Option<SessionModeState>Initial mode state if supported by the Agent
See protocol docs: Session Modes
config_options: Option<Vec<SessionConfigOption>>Initial session configuration options if supported by the Agent.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl NewSessionResponse
impl NewSessionResponse
Sourcepub fn new(session_id: impl Into<SessionId>) -> Self
pub fn new(session_id: impl Into<SessionId>) -> Self
Builds NewSessionResponse with the required response fields set; optional fields start unset or empty.
Sourcepub fn modes(self, modes: impl IntoOption<SessionModeState>) -> Self
pub fn modes(self, modes: impl IntoOption<SessionModeState>) -> Self
Initial mode state if supported by the Agent
See protocol docs: Session Modes
Sourcepub fn config_options(
self,
config_options: impl IntoOption<Vec<SessionConfigOption>>,
) -> Self
pub fn config_options( self, config_options: impl IntoOption<Vec<SessionConfigOption>>, ) -> Self
Initial session configuration options if supported by the Agent.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility