NoticeCapabilities

Struct NoticeCapabilities 

#[non_exhaustive]
pub struct NoticeCapabilities {}
Available on crate feature unstable_session_notices only.
UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Client support for presenting live advisory notices to the user.

Implementations

Source

impl NoticeCapabilities

pub fn new() -> Self

Advertises support for presenting live advisory notices to the user.