#[non_exhaustive]pub struct OtherMultiSelectItems {
pub type_: String,
pub fields: BTreeMap<String, Value>,
}Available on crate feature
unstable_elicitation only.Expand description
Custom or future typed item schema for multi-select properties.
This preserves unknown item type values and the rest of the items
payload for clients that store, replay, proxy, or forward elicitation
requests.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type_: StringCustom or future multi-select item type.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
fields: BTreeMap<String, Value>Additional fields from the unknown item schema payload.
Implementations