#[non_exhaustive]pub struct ProviderCurrentConfig {
pub api_type: LlmProtocol,
pub base_url: String,
pub meta: Option<Meta>,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Current effective non-secret routing configuration for a provider.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.api_type: LlmProtocolProtocol currently used by this provider.
base_url: StringBase URL currently used by this provider.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ProviderCurrentConfig
impl ProviderCurrentConfig
Sourcepub fn new(api_type: LlmProtocol, base_url: impl Into<String>) -> Self
Available on crate feature unstable_llm_providers only.
pub fn new(api_type: LlmProtocol, base_url: impl Into<String>) -> Self
unstable_llm_providers only.Builds ProviderCurrentConfig with the required fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
Available on crate feature unstable_llm_providers only.
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
unstable_llm_providers only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility