#[non_exhaustive]pub struct Range {
pub start: Position,
pub end: Position,
pub meta: Option<Meta>,
}Available on crate feature
unstable_nes only.Expand description
A range in a text document, expressed as start and end positions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start: PositionThe start position (inclusive).
end: PositionThe end position (exclusive).
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl Range
impl Range
Sourcepub fn new(start: Position, end: Position) -> Self
pub fn new(start: Position, end: Position) -> Self
Builds a Range from protocol coordinate values.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility