#[non_exhaustive]pub struct SessionConfigOptionsCapabilities {
pub boolean: Option<BooleanConfigOptionCapabilities>,
pub meta: Option<Meta>,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Session configuration option capabilities supported by the client.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.boolean: Option<BooleanConfigOptionCapabilities>Whether the client supports boolean session configuration options.
Omitted or null means the client does not advertise support.
Supplying {} means agents may include type: "boolean" entries in
configOptions, and the client may send session/set_config_option
requests with type: "boolean" and a boolean value.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl SessionConfigOptionsCapabilities
impl SessionConfigOptionsCapabilities
Sourcepub fn new() -> Self
Available on crate feature unstable_boolean_config only.
pub fn new() -> Self
unstable_boolean_config only.Builds an empty SessionConfigOptionsCapabilities; use builder methods to advertise supported sub-capabilities.
Sourcepub fn boolean(
self,
boolean: impl IntoOption<BooleanConfigOptionCapabilities>,
) -> Self
Available on crate feature unstable_boolean_config only.
pub fn boolean( self, boolean: impl IntoOption<BooleanConfigOptionCapabilities>, ) -> Self
unstable_boolean_config only.Whether the client supports boolean session configuration options.
Omitted or null means the client does not advertise support.
Supplying {} means agents may include type: "boolean" entries in
configOptions, and the client may send session/set_config_option
requests with type: "boolean" and a boolean value.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
Available on crate feature unstable_boolean_config only.
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
unstable_boolean_config only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility