#[non_exhaustive]pub struct SessionNotification {
pub session_id: SessionId,
pub update: SessionUpdate,
pub meta: Option<Meta>,
}Expand description
Notification containing a session update from the agent.
Used to stream real-time progress and results during prompt processing.
See protocol docs: Agent Reports Output
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdThe ID of the session this update pertains to.
update: SessionUpdateThe actual update content.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl SessionNotification
impl SessionNotification
Sourcepub fn new(session_id: impl Into<SessionId>, update: SessionUpdate) -> Self
pub fn new(session_id: impl Into<SessionId>, update: SessionUpdate) -> Self
Builds SessionNotification with the required notification fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility