#[non_exhaustive]pub struct SuggestNesRequest {
pub session_id: SessionId,
pub uri: String,
pub version: i64,
pub position: Position,
pub selection: Option<Range>,
pub trigger_kind: NesTriggerKind,
pub context: Option<NesSuggestContext>,
pub meta: Option<Meta>,
}unstable_nes only.Expand description
Request for a code suggestion.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdThe session ID for this request.
uri: StringThe URI of the document to suggest for.
version: i64The version number of the document.
position: PositionThe current cursor position.
selection: Option<Range>The current text selection range, if any.
trigger_kind: NesTriggerKindWhat triggered this suggestion request.
context: Option<NesSuggestContext>Context for the suggestion, included based on agent capabilities.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl SuggestNesRequest
impl SuggestNesRequest
Sourcepub fn new(
session_id: impl Into<SessionId>,
uri: impl Into<String>,
version: i64,
position: Position,
trigger_kind: NesTriggerKind,
) -> Self
pub fn new( session_id: impl Into<SessionId>, uri: impl Into<String>, version: i64, position: Position, trigger_kind: NesTriggerKind, ) -> Self
Builds SuggestNesRequest with the required request fields set; optional fields start unset or empty.
Sourcepub fn selection(self, selection: impl IntoOption<Range>) -> Self
pub fn selection(self, selection: impl IntoOption<Range>) -> Self
Sets or clears the optional selection field.
Sourcepub fn context(self, context: impl IntoOption<NesSuggestContext>) -> Self
pub fn context(self, context: impl IntoOption<NesSuggestContext>) -> Self
Sets or clears the optional context field.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility