#[non_exhaustive]pub struct TerminalExitStatus {
pub exit_code: Option<u32>,
pub signal: Option<String>,
pub meta: Option<Meta>,
}Expand description
Exit status of a terminal command.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.exit_code: Option<u32>The process exit code (may be null if terminated by signal).
signal: Option<String>The signal that terminated the process (may be null if exited normally).
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl TerminalExitStatus
impl TerminalExitStatus
Sourcepub fn new() -> Self
pub fn new() -> Self
Builds TerminalExitStatus with the required fields set; optional fields start unset or empty.
Sourcepub fn exit_code(self, exit_code: impl IntoOption<u32>) -> Self
pub fn exit_code(self, exit_code: impl IntoOption<u32>) -> Self
The process exit code (may be null if terminated by signal).
Sourcepub fn signal(self, signal: impl IntoOption<String>) -> Self
pub fn signal(self, signal: impl IntoOption<String>) -> Self
The signal that terminated the process (may be null if exited normally).
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility