#[non_exhaustive]pub struct TextDocumentContentChangeEvent {
pub range: Option<Range>,
pub text: String,
pub meta: Option<Meta>,
}unstable_nes only.Expand description
A content change event for a document.
When range is None, text is the full content of the document.
When range is Some, text replaces the given range.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.range: Option<Range>The range of the document that changed. If None, the entire content is replaced.
text: StringThe new text for the range, or the full document content if range is None.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl TextDocumentContentChangeEvent
impl TextDocumentContentChangeEvent
Sourcepub fn full(text: impl Into<String>) -> Self
pub fn full(text: impl Into<String>) -> Self
Builds a full-document change event that replaces the entire document text.
Sourcepub fn incremental(range: Range, text: impl Into<String>) -> Self
pub fn incremental(range: Range, text: impl Into<String>) -> Self
Builds an incremental document change event for a specific text range.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility