#[non_exhaustive]pub enum AgentResponse {
Show 18 variants
InitializeResponse(Box<InitializeResponse>),
LoginAuthResponse(Box<LoginAuthResponse>),
ListProvidersResponse(Box<ListProvidersResponse>),
SetProviderResponse(Box<SetProviderResponse>),
DisableProviderResponse(Box<DisableProviderResponse>),
LogoutAuthResponse(Box<LogoutAuthResponse>),
NewSessionResponse(Box<NewSessionResponse>),
ListSessionsResponse(Box<ListSessionsResponse>),
DeleteSessionResponse(Box<DeleteSessionResponse>),
ForkSessionResponse(Box<ForkSessionResponse>),
ResumeSessionResponse(Box<ResumeSessionResponse>),
CloseSessionResponse(Box<CloseSessionResponse>),
SetSessionConfigOptionResponse(Box<SetSessionConfigOptionResponse>),
PromptResponse(Box<PromptResponse>),
StartNesResponse(Box<StartNesResponse>),
SuggestNesResponse(Box<SuggestNesResponse>),
CloseNesResponse(Box<CloseNesResponse>),
ExtMethodResponse(Box<ExtResponse>),
}unstable_protocol_v2 only.Expand description
All possible responses that an agent can send to a client.
This enum is used internally for routing RPC responses. You typically won’t need to use this directly - the responses are handled automatically by the connection.
These are responses to the corresponding ClientRequest variants.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InitializeResponse(Box<InitializeResponse>)
Successful result returned for a initialize request.
LoginAuthResponse(Box<LoginAuthResponse>)
Successful result returned for an auth/login request.
ListProvidersResponse(Box<ListProvidersResponse>)
unstable_llm_providers only.Successful result returned for a providers/list request.
SetProviderResponse(Box<SetProviderResponse>)
unstable_llm_providers only.Successful result returned for a providers/set request.
DisableProviderResponse(Box<DisableProviderResponse>)
unstable_llm_providers only.Successful result returned for a providers/disable request.
LogoutAuthResponse(Box<LogoutAuthResponse>)
Successful result returned for an auth/logout request.
NewSessionResponse(Box<NewSessionResponse>)
Successful result returned for a session/new request.
ListSessionsResponse(Box<ListSessionsResponse>)
Successful result returned for a session/list request.
DeleteSessionResponse(Box<DeleteSessionResponse>)
Successful result returned for a session/delete request.
ForkSessionResponse(Box<ForkSessionResponse>)
unstable_session_fork only.Successful result returned for a session/fork request.
ResumeSessionResponse(Box<ResumeSessionResponse>)
Successful result returned for a session/resume request.
CloseSessionResponse(Box<CloseSessionResponse>)
Successful result returned for a session/close request.
SetSessionConfigOptionResponse(Box<SetSessionConfigOptionResponse>)
Successful result returned for a session/set_config_option request.
PromptResponse(Box<PromptResponse>)
Successful result returned for a session/prompt request.
StartNesResponse(Box<StartNesResponse>)
unstable_nes only.Successful result returned for a nes/start request.
SuggestNesResponse(Box<SuggestNesResponse>)
unstable_nes only.Successful result returned for a nes/suggest request.
CloseNesResponse(Box<CloseNesResponse>)
unstable_nes only.Successful result returned for a nes/close request.
ExtMethodResponse(Box<ExtResponse>)
Successful result returned by an extension method outside the core ACP method set.