#[non_exhaustive]pub enum AuthMethod {
Terminal(AuthMethodTerminal),
Agent(AuthMethodAgent),
Other(OtherAuthMethod),
}unstable_protocol_v2 only.Expand description
Describes an available authentication method.
The type field acts as the discriminator in the serialized JSON form.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Terminal(AuthMethodTerminal)
Client runs the configured agent program as a separate interactive
process, without passing this method to auth/login.
Agent(AuthMethodAgent)
Agent handles authentication itself through auth/login.
The type discriminator value is agent.
Other(OtherAuthMethod)
Custom or future authentication method.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
Clients that do not understand this method type should preserve the raw payload when storing, replaying, proxying, or forwarding initialization data, and otherwise ignore the method or display it generically.
Implementations
Sourceimpl AuthMethod
impl AuthMethod
Sourcepub fn method_id(&self) -> &AuthMethodId
pub fn method_id(&self) -> &AuthMethodId
The unique identifier for this authentication method.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Optional description providing more details about this authentication method.
Sourcepub fn meta(&self) -> Option<&Meta>
pub fn meta(&self) -> Option<&Meta>
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility