#[non_exhaustive]pub enum ElicitationScope {
Session(ElicitationSessionScope),
Request(ElicitationRequestScope),
}Available on crate features
unstable_elicitation and unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
The scope of an elicitation request, determining what context it’s tied to.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Session(ElicitationSessionScope)
Tied to a session, optionally to a specific tool call within that session.
Request(ElicitationRequestScope)
Tied to a specific JSON-RPC request outside of a session (e.g., during auth/configuration phases before any session is started).