#[non_exhaustive]pub enum LlmProtocol {
Anthropic,
OpenAi,
Azure,
Vertex,
Bedrock,
Other(String),
}Available on crate features
unstable_llm_providers and unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Well-known API protocol identifiers for LLM providers.
Agents and clients MUST handle unknown protocol identifiers gracefully.
Protocol names beginning with _ are free for custom use, like other ACP extension methods.
Protocol names that do not begin with _ are reserved for the ACP spec.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Anthropic
Anthropic API protocol.
OpenAi
OpenAI API protocol.
Azure
Azure OpenAI API protocol.
Vertex
Google Vertex AI API protocol.
Bedrock
AWS Bedrock API protocol.
Other(String)
Custom or future protocol.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.