#[non_exhaustive]pub enum NesRejectReason {
Rejected,
Ignored,
Replaced,
Cancelled,
Other(String),
}Available on crate features
unstable_nes and unstable_protocol_v2 only.Expand description
The reason a suggestion was rejected.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Rejected
The user explicitly dismissed the suggestion.
Ignored
The suggestion was shown but the user continued editing without interacting.
Replaced
The suggestion was superseded by a newer suggestion.
Cancelled
The request was cancelled before the agent returned a response.
Other(String)
Custom or future rejection reason.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.