#[non_exhaustive]pub enum NesSuggestion {
Edit(NesEditSuggestion),
Jump(NesJumpSuggestion),
Rename(NesRenameSuggestion),
SearchAndReplace(NesSearchAndReplaceSuggestion),
Other(OtherNesSuggestion),
}Available on crate features
unstable_nes and unstable_protocol_v2 only.Expand description
A suggestion returned by the agent.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Edit(NesEditSuggestion)
A text edit suggestion.
Jump(NesJumpSuggestion)
A jump-to-location suggestion.
Rename(NesRenameSuggestion)
A rename symbol suggestion.
SearchAndReplace(NesSearchAndReplaceSuggestion)
A search-and-replace suggestion.
Other(OtherNesSuggestion)
Custom or future NES suggestion.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
Receivers that do not understand this suggestion kind should preserve the raw payload when storing, replaying, proxying, or forwarding suggestions, and otherwise ignore it or display it generically.