#[non_exhaustive]pub enum PlanUpdateContent {
Items(PlanItems),
File(PlanFile),
Markdown(PlanMarkdown),
Other(OtherPlanUpdateContent),
}unstable_protocol_v2 only.Expand description
Updated content for a plan.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Items(PlanItems)
Structured plan entries.
File(PlanFile)
unstable_plan_operations only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
A URI pointing to a file containing the plan.
Markdown(PlanMarkdown)
unstable_plan_operations only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Raw markdown content for the plan.
Other(OtherPlanUpdateContent)
Custom or future plan update content.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
Receivers that do not understand this content type should preserve the raw payload when storing, replaying, proxying, or forwarding plans, and otherwise ignore it or display it generically.
Implementations
Sourceimpl PlanUpdateContent
impl PlanUpdateContent
Sourcepub fn items(id: impl Into<PlanId>, entries: Vec<PlanEntry>) -> Self
pub fn items(id: impl Into<PlanId>, entries: Vec<PlanEntry>) -> Self
Builds a plan update that replaces the itemized entries for a plan.