#[non_exhaustive]pub enum ReplayFrom {
Start(ReplayFromStart),
Other(OtherReplayFrom),
}Available on crate feature
unstable_protocol_v2 only.Expand description
Inclusive cursor describing where replayed session history should begin.
Replay includes the position identified by the cursor.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Start(ReplayFromStart)
Replay the whole conversation from its first replayable entry.
Other(OtherReplayFrom)
Custom or future replay cursor.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
Receivers that do not understand this cursor should preserve the raw payload when storing, replaying, proxying, or forwarding requests, and otherwise reject the request rather than guessing where to replay from.