#[non_exhaustive]pub enum RequestPermissionOutcome {
Cancelled,
Selected(SelectedPermissionOutcome),
Other(OtherRequestPermissionOutcome),
}unstable_protocol_v2 only.Expand description
The outcome of a permission request.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Cancelled
Active session work was cancelled before the user responded.
When a client sends a session/cancel notification to cancel active
session work, it MUST respond to all pending session/request_permission
requests with this Cancelled outcome.
See protocol docs: Cancellation
Selected(SelectedPermissionOutcome)
The user selected one of the provided options.
Other(OtherRequestPermissionOutcome)
Custom or future permission outcome.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
Agents that do not understand this outcome MUST NOT treat it as approval. They should preserve the raw payload when storing, replaying, proxying, or forwarding permission responses, and otherwise fail or decline the permission request according to policy.