#[non_exhaustive]pub enum StopReason {
EndTurn,
MaxTokens,
MaxTurnRequests,
Refusal,
Cancelled,
Other(String),
}unstable_protocol_v2 only.Expand description
Reasons why an agent stops active session work.
See protocol docs: Stop Reasons
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EndTurn
The active work ended successfully.
MaxTokens
The active work ended because the agent reached the maximum number of tokens.
MaxTurnRequests
The active work ended because the agent reached the maximum number of allowed agent requests before returning idle.
Refusal
The active work ended because the agent refused to continue. The user prompt and everything that comes after it won’t be included in the next prompt, so this should be reflected in the UI.
Cancelled
Active session work was cancelled by the client via session/cancel.
Agents should report this stop reason on an idle state_update session update
when cancellation succeeds, even if cancellation causes exceptions in
underlying operations.
Other(String)
Custom or future stop reason.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.