#[non_exhaustive]pub struct ClientNesCapabilities {
pub jump: Option<NesJumpCapabilities>,
pub rename: Option<NesRenameCapabilities>,
pub search_and_replace: Option<NesSearchAndReplaceCapabilities>,
pub meta: Option<Meta>,
}Available on crate features
unstable_nes and unstable_protocol_v2 only.Expand description
NES capabilities advertised by the client during initialization.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.jump: Option<NesJumpCapabilities>Whether the client supports the jump suggestion kind.
rename: Option<NesRenameCapabilities>Whether the client supports the rename suggestion kind.
search_and_replace: Option<NesSearchAndReplaceCapabilities>Whether the client supports the searchAndReplace suggestion kind.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ClientNesCapabilities
impl ClientNesCapabilities
pub fn new() -> Self
pub fn jump(self, jump: impl IntoOption<NesJumpCapabilities>) -> Self
pub fn rename(self, rename: impl IntoOption<NesRenameCapabilities>) -> Self
pub fn search_and_replace( self, search_and_replace: impl IntoOption<NesSearchAndReplaceCapabilities>, ) -> Self
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility