CommandPermissionSubject

Struct CommandPermissionSubject 

#[non_exhaustive]
pub struct CommandPermissionSubject { pub command: String, pub cwd: AbsolutePath, pub tool_call_id: Option<ToolCallId>, pub terminal_id: Option<TerminalId>, pub meta: Option<Meta>, }
Available on crate feature unstable_protocol_v2 only.
Permission request details for a command.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
command: String

The command that would be run if permission is granted.

cwd: AbsolutePath

The absolute working directory for the command.

tool_call_id: Option<ToolCallId>

The associated tool call, when known. Omitted and null are equivalent.

terminal_id: Option<TerminalId>

The associated terminal, when already known. Omitted and null are equivalent.

meta: Option<Meta>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys. Omitted and null are equivalent and mean no subject metadata was provided.

See protocol docs: Extensibility

Implementations

Source

impl CommandPermissionSubject

pub fn new(command: impl Into<String>, cwd: impl Into<AbsolutePath>) -> Self

Builds command permission details with the required command and working directory.

pub fn tool_call_id(self, tool_call_id: impl IntoOption<ToolCallId>) -> Self

Sets or clears the associated tool-call ID.

pub fn terminal_id(self, terminal_id: impl IntoOption<TerminalId>) -> Self

Sets or clears the associated terminal ID.

pub fn meta(self, meta: impl IntoOption<Meta>) -> Self

Sets or clears subject-scoped metadata.