#[non_exhaustive]pub struct ConnectMcpRequest {
pub acp_id: McpServerAcpId,
pub meta: Option<Meta>,
}unstable_mcp_over_acp and unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Request parameters for mcp/connect.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.acp_id: McpServerAcpIdThe ACP MCP server ID that was provided by the component declaring the MCP server.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ConnectMcpRequest
impl ConnectMcpRequest
Sourcepub fn new(acp_id: impl Into<McpServerAcpId>) -> Self
pub fn new(acp_id: impl Into<McpServerAcpId>) -> Self
Builds ConnectMcpRequest with the required request fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility