#[non_exhaustive]pub struct CreateElicitationResponse {
pub action: ElicitationAction,
pub meta: Option<Meta>,
}unstable_protocol_v2 only.Expand description
Response from the client to an elicitation request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.action: ElicitationActionThe user’s action in response to the elicitation.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
Optional. Omitted and null are equivalent and mean no metadata.
See protocol docs: Extensibility
Implementations
Sourceimpl CreateElicitationResponse
impl CreateElicitationResponse
Sourcepub fn new(action: impl Into<ElicitationAction>) -> Self
pub fn new(action: impl Into<ElicitationAction>) -> Self
Builds CreateElicitationResponse with the required response fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
Optional. Omitted and null are equivalent and mean no metadata.
See protocol docs: Extensibility