#[non_exhaustive]pub struct Diff {
pub changes: Vec<DiffChange>,
pub patch: Option<DiffPatch>,
pub meta: Option<Meta>,
}unstable_protocol_v2 only.Expand description
File changes produced by a tool call.
changes identifies affected absolute paths and operations. patch
optionally carries renderable patch text for clients that can show it.
Agents SHOULD provide patch whenever feasible. Clients MUST handle diffs
where patch is omitted or null.
See protocol docs: Content
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.changes: Vec<DiffChange>Structured file changes described by this diff.
Clients can use this field without parsing patch text to determine affected paths.
patch: Option<DiffPatch>Renderable patch text.
Agents SHOULD provide patch text whenever feasible. Omitted or null
means no renderable patch text was provided.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl Diff
impl Diff
Sourcepub fn new(changes: Vec<DiffChange>) -> Self
pub fn new(changes: Vec<DiffChange>) -> Self
Builds Diff with structured file changes.
Sourcepub fn patch(diff: impl Into<String>, changes: Vec<DiffChange>) -> Self
pub fn patch(diff: impl Into<String>, changes: Vec<DiffChange>) -> Self
Builds Diff with git patch text and structured file changes.
Sourcepub fn with_patch(self, patch: impl IntoOption<DiffPatch>) -> Self
pub fn with_patch(self, patch: impl IntoOption<DiffPatch>) -> Self
Sets renderable patch text.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility