#[non_exhaustive]pub struct ElicitationAcceptAction {
pub content: Option<BTreeMap<String, ElicitationContentValue>>,
}Available on crate features
unstable_elicitation and unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
The user accepted the elicitation and provided content.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.content: Option<BTreeMap<String, ElicitationContentValue>>The user-provided content, if any, as an object matching the requested schema.
Implementations
Sourceimpl ElicitationAcceptAction
impl ElicitationAcceptAction
pub fn new() -> Self
Sourcepub fn content(
self,
content: impl IntoOption<BTreeMap<String, ElicitationContentValue>>,
) -> Self
pub fn content( self, content: impl IntoOption<BTreeMap<String, ElicitationContentValue>>, ) -> Self
The user-provided content as an object matching the requested schema.