#[non_exhaustive]pub struct ElicitationCapabilities {
pub form: Option<ElicitationFormCapabilities>,
pub url: Option<ElicitationUrlCapabilities>,
pub meta: Option<Meta>,
}unstable_elicitation and unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Elicitation capabilities supported by the client.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.form: Option<ElicitationFormCapabilities>Whether the client supports form-based elicitation.
url: Option<ElicitationUrlCapabilities>Whether the client supports URL-based elicitation.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ElicitationCapabilities
impl ElicitationCapabilities
pub fn new() -> Self
Sourcepub fn form(self, form: impl IntoOption<ElicitationFormCapabilities>) -> Self
pub fn form(self, form: impl IntoOption<ElicitationFormCapabilities>) -> Self
Whether the client supports form-based elicitation.
Sourcepub fn url(self, url: impl IntoOption<ElicitationUrlCapabilities>) -> Self
pub fn url(self, url: impl IntoOption<ElicitationUrlCapabilities>) -> Self
Whether the client supports URL-based elicitation.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility