#[non_exhaustive]pub struct ElicitationFormMode {
pub scope: ElicitationScope,
pub requested_schema: ElicitationSchema,
}Available on crate features
unstable_elicitation and unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Form-based elicitation mode where the client renders a form from the provided schema.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.scope: ElicitationScopeThe scope this elicitation is tied to.
requested_schema: ElicitationSchemaA JSON Schema describing the form fields to present to the user.
Implementations
Sourceimpl ElicitationFormMode
impl ElicitationFormMode
pub fn new( scope: impl Into<ElicitationScope>, requested_schema: ElicitationSchema, ) -> Self