#[non_exhaustive]pub struct EmbeddedResource {
pub annotations: Option<Annotations>,
pub resource: EmbeddedResourceResource,
pub meta: Option<Meta>,
}unstable_protocol_v2 only.Expand description
The contents of a resource, embedded into a prompt or tool call result.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.annotations: Option<Annotations>Optional annotations that help clients decide how to display or route this content.
resource: EmbeddedResourceResourceEmbedded resource payload, either text or binary data.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl EmbeddedResource
impl EmbeddedResource
Sourcepub fn new(resource: EmbeddedResourceResource) -> Self
pub fn new(resource: EmbeddedResourceResource) -> Self
Builds EmbeddedResource with its required content payload; optional annotations and metadata start unset.
Sourcepub fn annotations(self, annotations: impl IntoOption<Annotations>) -> Self
pub fn annotations(self, annotations: impl IntoOption<Annotations>) -> Self
Sets or clears the optional annotations field.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility