Error

Struct Error 

#[non_exhaustive]
pub struct Error { pub code: ErrorCode, pub message: String, pub data: Option<Value>, }
Available on crate feature unstable_protocol_v2 only.
JSON-RPC error object.

Represents an error that occurred during method execution, following the JSON-RPC 2.0 error object specification with optional additional data.

See protocol docs: JSON-RPC Error Object

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
code: ErrorCode

A number indicating the error type that occurred. This must be an integer as defined in the JSON-RPC specification.

message: String

A string providing a short description of the error. The message should be limited to a concise single sentence.

data: Option<Value>

Optional primitive or structured value that contains additional information about the error. This may include debugging information or context-specific details.

Implementations

Source

impl Error

pub fn new(code: i32, message: impl Into<String>) -> Self

Creates a new error with the given code and message.

The code parameter can be an ErrorCode constant or a tuple of (code, message).

pub fn data(self, data: impl IntoOption<Value>) -> Self

Adds additional data to the error.

This method is chainable and allows attaching context-specific information to help with debugging or provide more details about the error.

pub fn parse_error() -> Self

Invalid JSON was received by the server. An error occurred on the server while parsing the JSON text.

pub fn invalid_request() -> Self

The JSON sent is not a valid Request object.

pub fn method_not_found() -> Self

The method does not exist / is not available.

pub fn invalid_params() -> Self

Invalid method parameter(s).

pub fn internal_error() -> Self

Internal JSON-RPC error.

pub fn request_cancelled() -> Self

Available on crate feature unstable_cancel_request only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Request was cancelled.

Execution of the method was aborted either due to a cancellation request from the caller or because of resource constraints or shutdown.

pub fn auth_required() -> Self

Authentication required.

pub fn url_elicitation_required() -> Self

Available on crate feature unstable_elicitation only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

The agent requires user input via a URL-based elicitation before it can proceed.

pub fn resource_not_found(uri: Option<String>) -> Self

A given resource, such as a file, was not found.

pub fn into_internal_error(err: impl Error) -> Self

Converts a standard error into an internal JSON-RPC error.

The error’s string representation is included as additional data.