Icon

Struct Icon 

#[non_exhaustive]
pub struct Icon { pub src: String, pub mime_type: Option<MediaType>, pub sizes: Option<Vec<String>>, pub theme: Option<IconTheme>, }
Available on crate feature unstable_protocol_v2 only.
An optionally-sized icon that can be displayed in a user interface.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
src: String

A standard URI pointing to an icon resource.

mime_type: Option<MediaType>

Optional MIME type override if the source MIME type is missing or generic.

sizes: Option<Vec<String>>

Optional array of strings that specify sizes at which the icon can be used. Each string should be in WxH format (e.g., "48x48", "96x96") or "any" for scalable formats like SVG.

If not provided, the client should assume that the icon can be used at any size.

theme: Option<IconTheme>

Optional theme this icon is designed for.

Implementations

Source

impl Icon

pub fn new(src: impl Into<String>) -> Self

Builds Icon with the required source URI; optional display hints start unset.

pub fn mime_type(self, mime_type: impl IntoOption<MediaType>) -> Self

Sets or clears the optional mimeType field.

pub fn sizes(self, sizes: impl IntoOption<Vec<String>>) -> Self

Sets or clears the optional sizes at which the icon can be used.

pub fn theme(self, theme: impl IntoOption<IconTheme>) -> Self

Sets or clears the optional theme field.