#[non_exhaustive]pub struct InitializeResponse {
pub protocol_version: ProtocolVersion,
pub capabilities: AgentCapabilities,
pub auth_methods: Vec<AuthMethod>,
pub agent_info: Option<Implementation>,
pub meta: Option<Meta>,
}unstable_protocol_v2 only.Expand description
Response to the initialize method.
Contains the negotiated protocol version and agent capabilities.
See protocol docs: Initialization
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.protocol_version: ProtocolVersionThe protocol version the client specified if supported by the agent, or the latest protocol version supported by the agent.
The client should disconnect, if it doesn’t support this version.
capabilities: AgentCapabilitiesCapabilities supported by the agent.
auth_methods: Vec<AuthMethod>Authentication methods supported by the agent.
agent_info: Option<Implementation>Information about the Agent name and version sent to the Client.
Note: in future versions of the protocol, this will be required.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl InitializeResponse
impl InitializeResponse
Sourcepub fn new(protocol_version: ProtocolVersion) -> Self
pub fn new(protocol_version: ProtocolVersion) -> Self
Builds InitializeResponse with the required response fields set; optional fields start unset or empty.
Sourcepub fn capabilities(self, capabilities: AgentCapabilities) -> Self
pub fn capabilities(self, capabilities: AgentCapabilities) -> Self
Capabilities supported by the agent.
Sourcepub fn auth_methods(self, auth_methods: Vec<AuthMethod>) -> Self
pub fn auth_methods(self, auth_methods: Vec<AuthMethod>) -> Self
Authentication methods supported by the agent.
Sourcepub fn agent_info(self, agent_info: impl IntoOption<Implementation>) -> Self
pub fn agent_info(self, agent_info: impl IntoOption<Implementation>) -> Self
Information about the Agent name and version sent to the Client.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility