#[non_exhaustive]pub struct LoginAuthRequest {
pub method_id: AuthMethodId,
pub meta: Option<Meta>,
}unstable_protocol_v2 only.Expand description
Request parameters for the auth/login method.
Specifies which authentication method to use.
Agents MUST support this method when their initialize response advertised
at least one valid authentication method. Clients MUST NOT call this method
when authMethods was omitted or empty.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.method_id: AuthMethodIdThe ID of the authentication method to use. Must be one of the methods advertised in the initialize response.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl LoginAuthRequest
impl LoginAuthRequest
Sourcepub fn new(method_id: impl Into<AuthMethodId>) -> Self
pub fn new(method_id: impl Into<AuthMethodId>) -> Self
Builds LoginAuthRequest with the required request fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility