#[non_exhaustive]pub struct McpRequestId(pub Arc<str>);Available on crate features
unstable_mcp_over_acp and unstable_protocol_v2 only.Expand description
UNSTABLE
Identifies an inner MCP request active against a server on this ACP connection. Generated by the caller and preserved unchanged by proxies, independently of the outer ACP JSON-RPC request ID.
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: Arc<str>Implementations
Sourceimpl McpRequestId
impl McpRequestId