McpStdioCapabilities

Struct McpStdioCapabilities 

#[non_exhaustive]
pub struct McpStdioCapabilities { pub meta: Option<Meta>, }
Available on crate feature unstable_protocol_v2 only.
Capabilities for stdio MCP server transports.

Supplying {} means the agent supports stdio MCP server transports.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
meta: Option<Meta>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl McpStdioCapabilities

pub fn new() -> Self

pub fn meta(self, meta: impl IntoOption<Meta>) -> Self

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility