#[non_exhaustive]pub struct NesEditSuggestion {
pub id: String,
pub uri: String,
pub edits: Vec<NesTextEdit>,
pub cursor_position: Option<Position>,
pub meta: Option<Meta>,
}unstable_nes and unstable_protocol_v2 only.Expand description
A text edit suggestion.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringUnique identifier for accept/reject tracking.
uri: StringThe URI of the file to edit.
edits: Vec<NesTextEdit>The text edits to apply.
cursor_position: Option<Position>Optional suggested cursor position after applying edits.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl NesEditSuggestion
impl NesEditSuggestion
Sourcepub fn new(
id: impl Into<String>,
uri: impl Into<String>,
edits: Vec<NesTextEdit>,
) -> Self
pub fn new( id: impl Into<String>, uri: impl Into<String>, edits: Vec<NesTextEdit>, ) -> Self
Builds NesEditSuggestion with the required fields set; optional fields start unset or empty.
Sourcepub fn cursor_position(self, cursor_position: impl IntoOption<Position>) -> Self
pub fn cursor_position(self, cursor_position: impl IntoOption<Position>) -> Self
Sets or clears the optional cursorPosition field.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility