#[non_exhaustive]pub struct NesEventCapabilities {
pub document: Option<NesDocumentEventCapabilities>,
pub meta: Option<Meta>,
}Available on crate features
unstable_nes and unstable_protocol_v2 only.Expand description
Event capabilities the agent can consume.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.document: Option<NesDocumentEventCapabilities>Document event capabilities.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl NesEventCapabilities
impl NesEventCapabilities
pub fn new() -> Self
pub fn document( self, document: impl IntoOption<NesDocumentEventCapabilities>, ) -> Self
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility