#[non_exhaustive]pub struct NesJumpSuggestion {
pub id: String,
pub uri: String,
pub position: Position,
pub meta: Option<Meta>,
}Available on crate features
unstable_nes and unstable_protocol_v2 only.Expand description
A jump-to-location suggestion.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringUnique identifier for accept/reject tracking.
uri: StringThe file to navigate to.
position: PositionThe target position within the file.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl NesJumpSuggestion
impl NesJumpSuggestion
Sourcepub fn new(
id: impl Into<String>,
uri: impl Into<String>,
position: Position,
) -> Self
pub fn new( id: impl Into<String>, uri: impl Into<String>, position: Position, ) -> Self
Builds NesJumpSuggestion with the required fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility