#[non_exhaustive]pub struct NesSuggestContext {
pub recent_files: Option<Vec<NesRecentFile>>,
pub related_snippets: Option<Vec<NesRelatedSnippet>>,
pub edit_history: Option<Vec<NesEditHistoryEntry>>,
pub user_actions: Option<Vec<NesUserAction>>,
pub open_files: Option<Vec<NesOpenFile>>,
pub diagnostics: Option<Vec<NesDiagnostic>>,
pub meta: Option<Meta>,
}Available on crate features
unstable_nes and unstable_protocol_v2 only.Expand description
Context attached to a suggestion request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.recent_files: Option<Vec<NesRecentFile>>Recently accessed files.
Related code snippets.
edit_history: Option<Vec<NesEditHistoryEntry>>Recent edit history.
user_actions: Option<Vec<NesUserAction>>Recent user actions (typing, navigation, etc.).
open_files: Option<Vec<NesOpenFile>>Currently open files in the editor.
diagnostics: Option<Vec<NesDiagnostic>>Current diagnostics (errors, warnings).
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl NesSuggestContext
impl NesSuggestContext
pub fn new() -> Self
pub fn recent_files( self, recent_files: impl IntoOption<Vec<NesRecentFile>>, ) -> Self
pub fn edit_history( self, edit_history: impl IntoOption<Vec<NesEditHistoryEntry>>, ) -> Self
pub fn user_actions( self, user_actions: impl IntoOption<Vec<NesUserAction>>, ) -> Self
pub fn open_files(self, open_files: impl IntoOption<Vec<NesOpenFile>>) -> Self
pub fn diagnostics( self, diagnostics: impl IntoOption<Vec<NesDiagnostic>>, ) -> Self
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility