#[non_exhaustive]pub struct NesUserAction {
pub action: String,
pub uri: String,
pub position: Position,
pub timestamp_ms: u64,
pub meta: Option<Meta>,
}unstable_nes and unstable_protocol_v2 only.Expand description
A user action (typing, cursor movement, etc.).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.action: StringThe kind of action (e.g., “insertChar”, “cursorMovement”).
uri: StringThe URI of the file where the action occurred.
position: PositionThe position where the action occurred.
timestamp_ms: u64Timestamp in milliseconds since epoch.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl NesUserAction
impl NesUserAction
Sourcepub fn new(
action: impl Into<String>,
uri: impl Into<String>,
position: Position,
timestamp_ms: u64,
) -> Self
pub fn new( action: impl Into<String>, uri: impl Into<String>, position: Position, timestamp_ms: u64, ) -> Self
Builds NesUserAction with the required fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility