#[non_exhaustive]pub struct NewSessionResponse {
pub session_id: SessionId,
pub config_options: Option<Vec<SessionConfigOption>>,
pub meta: Option<Meta>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
Response from creating a new session.
See protocol docs: Creating a Session
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdUnique identifier for the created session.
Used in all subsequent requests for this conversation.
config_options: Option<Vec<SessionConfigOption>>Initial session configuration options if supported by the Agent.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl NewSessionResponse
impl NewSessionResponse
pub fn new(session_id: impl Into<SessionId>) -> Self
Sourcepub fn config_options(
self,
config_options: impl IntoOption<Vec<SessionConfigOption>>,
) -> Self
pub fn config_options( self, config_options: impl IntoOption<Vec<SessionConfigOption>>, ) -> Self
Initial session configuration options if supported by the Agent.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility