#[non_exhaustive]pub struct OtherAuthMethod {
pub type_: String,
pub id: AuthMethodId,
pub name: String,
pub description: Option<String>,
pub meta: Option<Meta>,
pub fields: BTreeMap<String, Value>,
}unstable_protocol_v2 only.Expand description
Custom or future authentication method payload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type_: StringCustom or future authentication method type.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
id: AuthMethodIdUnique identifier for this authentication method.
name: StringHuman-readable name of the authentication method.
description: Option<String>Optional description providing more details about this authentication method.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
fields: BTreeMap<String, Value>Additional fields from the unknown authentication method payload.
Implementations
Sourceimpl OtherAuthMethod
impl OtherAuthMethod
pub fn new( type_: impl Into<String>, id: impl Into<AuthMethodId>, name: impl Into<String>, fields: BTreeMap<String, Value>, ) -> Self
Sourcepub fn description(self, description: impl IntoOption<String>) -> Self
pub fn description(self, description: impl IntoOption<String>) -> Self
Optional description providing more details about this authentication method.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility