#[non_exhaustive]pub struct OtherElicitationMode {
pub mode: String,
pub scope: ElicitationScope,
pub fields: BTreeMap<String, Value>,
}Available on crate features
unstable_elicitation and unstable_protocol_v2 only.Expand description
Custom or future elicitation mode payload.
This preserves the unknown mode discriminator and the rest of the mode
object for clients that store, replay, proxy, or forward elicitation
requests.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.mode: StringCustom or future elicitation mode.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
scope: ElicitationScopeThe scope this elicitation is tied to.
fields: BTreeMap<String, Value>Additional fields from the unknown elicitation mode payload.
Implementations
Sourceimpl OtherElicitationMode
impl OtherElicitationMode
Sourcepub fn new(
mode: impl Into<String>,
scope: impl Into<ElicitationScope>,
fields: BTreeMap<String, Value>,
) -> Self
pub fn new( mode: impl Into<String>, scope: impl Into<ElicitationScope>, fields: BTreeMap<String, Value>, ) -> Self
Builds OtherElicitationMode from an unknown discriminator and preserves the remaining extension fields.