#[non_exhaustive]pub struct OtherStateUpdate {
pub state: String,
pub fields: BTreeMap<String, Value>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
Custom or future session state payload.
This preserves the unknown state discriminator and the rest of the state
object for clients that store, replay, proxy, or forward session history.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.state: StringCustom or future session state.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
fields: BTreeMap<String, Value>Additional fields from the unknown state payload.
Implementations