#[non_exhaustive]pub struct PlanMarkdown {
pub id: PlanId,
pub content: String,
pub meta: Option<Meta>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
A plan represented as raw markdown content.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: PlanIdThe plan ID to update.
content: StringMarkdown content for the plan.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl PlanMarkdown
impl PlanMarkdown
pub fn new(id: impl Into<PlanId>, content: impl Into<String>) -> Self
Available on crate feature
unstable_plan_operations only.Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
Available on crate feature unstable_plan_operations only.
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
unstable_plan_operations only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility