#[non_exhaustive]pub struct PromptCapabilities {
pub image: Option<PromptImageCapabilities>,
pub audio: Option<PromptAudioCapabilities>,
pub embedded_context: Option<PromptEmbeddedContextCapabilities>,
pub meta: Option<Meta>,
}unstable_protocol_v2 only.Expand description
Prompt capabilities supported by the agent in session/prompt requests.
Baseline agent functionality requires support for ContentBlock::Text
and ContentBlock::ResourceLink in prompt requests.
Other variants must be explicitly opted in to. Capabilities for different types of content in prompt requests.
Indicates which content types beyond the baseline (text and resource links) the agent can process.
See protocol docs: Prompt Capabilities
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.image: Option<PromptImageCapabilities>Agent supports ContentBlock::Image.
Optional. Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports image content in prompts.
audio: Option<PromptAudioCapabilities>Agent supports ContentBlock::Audio.
Optional. Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports audio content in prompts.
embedded_context: Option<PromptEmbeddedContextCapabilities>Agent supports embedded context in session/prompt requests.
When enabled, the Client is allowed to include ContentBlock::Resource
in prompt requests for pieces of context that are referenced in the message.
Optional. Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports embedded context in prompts.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl PromptCapabilities
impl PromptCapabilities
pub fn new() -> Self
Sourcepub fn image(self, image: impl IntoOption<PromptImageCapabilities>) -> Self
pub fn image(self, image: impl IntoOption<PromptImageCapabilities>) -> Self
Agent supports ContentBlock::Image.
Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports image content in prompts.
Sourcepub fn audio(self, audio: impl IntoOption<PromptAudioCapabilities>) -> Self
pub fn audio(self, audio: impl IntoOption<PromptAudioCapabilities>) -> Self
Agent supports ContentBlock::Audio.
Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports audio content in prompts.
Sourcepub fn embedded_context(
self,
embedded_context: impl IntoOption<PromptEmbeddedContextCapabilities>,
) -> Self
pub fn embedded_context( self, embedded_context: impl IntoOption<PromptEmbeddedContextCapabilities>, ) -> Self
Agent supports embedded context in session/prompt requests.
When enabled, the Client is allowed to include ContentBlock::Resource
in prompt requests for pieces of context that are referenced in the message.
Omitted or null both mean the agent does not advertise support.
Supplying {} means the agent supports embedded context in prompts.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility