#[non_exhaustive]pub struct PromptResponse {
pub meta: Option<Meta>,
}unstable_protocol_v2 only.Expand description
Response acknowledging that a user prompt was accepted.
This response does not indicate that the agent has finished processing.
Agents report session state through state_update session updates.
See protocol docs: Prompt Accepted
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl PromptResponse
impl PromptResponse
Sourcepub fn new() -> Self
pub fn new() -> Self
Builds PromptResponse with the required response fields set; optional fields start unset or empty.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility