#[non_exhaustive]pub struct ProviderCurrentConfig {
pub api_type: LlmProtocol,
pub base_url: String,
}Available on crate features
unstable_llm_providers and unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Current effective non-secret routing configuration for a provider.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.api_type: LlmProtocolProtocol currently used by this provider.
base_url: StringBase URL currently used by this provider.
Implementations
Sourceimpl ProviderCurrentConfig
impl ProviderCurrentConfig
pub fn new(api_type: LlmProtocol, base_url: impl Into<String>) -> Self