ProviderInfo

Struct ProviderInfo 

#[non_exhaustive]
pub struct ProviderInfo { pub id: String, pub supported: Vec<LlmProtocol>, pub required: bool, pub current: Option<ProviderCurrentConfig>, pub meta: Option<Meta>, }
Available on crate feature unstable_protocol_v2 only.
UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Information about a configurable LLM provider.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
id: String

Provider identifier, for example “main” or “openai”.

supported: Vec<LlmProtocol>

Supported protocol types for this provider.

required: bool

Whether this provider is mandatory and cannot be disabled via providers/disable. If true, clients must not call providers/disable for this id.

current: Option<ProviderCurrentConfig>

Current effective non-secret routing config. Null or omitted means provider is disabled.

meta: Option<Meta>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl ProviderInfo

pub fn new( id: impl Into<String>, supported: Vec<LlmProtocol>, required: bool, current: impl IntoOption<ProviderCurrentConfig>, ) -> Self

Available on crate feature unstable_llm_providers only.
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self

Available on crate feature unstable_llm_providers only.

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility