#[non_exhaustive]pub struct SessionCancelCapabilities {
pub meta: Option<Meta>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Capability to cancel work in a subagent session without ending that session.
Supplying {} advertises support; an omitted or null cancel does not.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl SessionCancelCapabilities
impl SessionCancelCapabilities
Sourcepub fn new() -> Self
Available on crate feature unstable_subagents only.
pub fn new() -> Self
unstable_subagents only.Builds an empty capability object advertising cancellation support.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
Available on crate feature unstable_subagents only.
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
unstable_subagents only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility