#[non_exhaustive]pub struct SetSessionConfigOptionRequest {
pub session_id: SessionId,
pub config_id: SessionConfigId,
pub value: SessionConfigOptionValue,
pub meta: Option<Meta>,
}unstable_protocol_v2 only.Expand description
Request parameters for setting a session configuration option.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdThe ID of the session to set the configuration option for.
config_id: SessionConfigIdThe ID of the configuration option to set.
value: SessionConfigOptionValueunstable_boolean_config only.The value to set, including a type discriminator and the raw value.
When type is absent on the wire, defaults to treating the value as a
SessionConfigValueId for select options.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl SetSessionConfigOptionRequest
impl SetSessionConfigOptionRequest
pub fn new( session_id: impl Into<SessionId>, config_id: impl Into<SessionConfigId>, value: impl Into<SessionConfigOptionValue>, ) -> Self
unstable_boolean_config only.Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility