#[non_exhaustive]pub struct StartNesRequest {
pub workspace_uri: Option<String>,
pub workspace_folders: Option<Vec<WorkspaceFolder>>,
pub repository: Option<NesRepository>,
pub meta: Option<Meta>,
}Available on crate features
unstable_nes and unstable_protocol_v2 only.Expand description
Request to start an NES session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workspace_uri: Option<String>The root URI of the workspace.
workspace_folders: Option<Vec<WorkspaceFolder>>The workspace folders.
repository: Option<NesRepository>Repository metadata, if the workspace is a git repository.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl StartNesRequest
impl StartNesRequest
pub fn new() -> Self
pub fn workspace_uri(self, workspace_uri: impl IntoOption<String>) -> Self
pub fn workspace_folders( self, workspace_folders: impl IntoOption<Vec<WorkspaceFolder>>, ) -> Self
pub fn repository(self, repository: impl IntoOption<NesRepository>) -> Self
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility