#[non_exhaustive]pub struct Terminal {
pub terminal_id: TerminalId,
pub meta: Option<Meta>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
A display-only reference to an agent-owned terminal.
Terminal state and output are delivered separately through
TerminalUpdate and TerminalOutputChunk.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.terminal_id: TerminalIdThe ID of the terminal to display.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys. This metadata is scoped to the content reference. Omitted
and null are equivalent and mean no item metadata was provided.
See protocol docs: Extensibility
Implementations