#[non_exhaustive]pub struct TerminalAuthCapabilities {
pub meta: Option<Meta>,
}unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Capabilities for terminal authentication methods.
Supplying {} means the client supports terminal authentication methods.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl TerminalAuthCapabilities
impl TerminalAuthCapabilities
Sourcepub fn new() -> Self
Available on crate feature unstable_auth_methods only.
pub fn new() -> Self
unstable_auth_methods only.Builds an empty TerminalAuthCapabilities; use builder methods to advertise supported sub-capabilities.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
Available on crate feature unstable_auth_methods only.
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
unstable_auth_methods only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility