#[non_exhaustive]pub struct TerminalOutput {
pub data: String,
pub meta: Option<Meta>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
An authoritative replacement snapshot of terminal output bytes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.data: StringBase64-encoded replacement terminal output bytes.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys. This metadata is scoped to the replacement snapshot. Omitted
and null are equivalent and mean no snapshot metadata was provided.
See protocol docs: Extensibility
Implementations