#[non_exhaustive]pub struct TerminalOutputChunk {
pub terminal_id: TerminalId,
pub data: String,
pub meta: Option<Meta>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
A chunk of bytes appended to an agent-owned terminal’s output.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.terminal_id: TerminalIdThe terminal receiving these bytes.
data: StringIndependently base64-encoded terminal output bytes.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys. This field is chunk-scoped. Omitted and null are
equivalent and mean no chunk metadata was provided.
See protocol docs: Extensibility
Implementations
Sourceimpl TerminalOutputChunk
impl TerminalOutputChunk
Sourcepub fn new(terminal_id: impl Into<TerminalId>, data: impl Into<String>) -> Self
pub fn new(terminal_id: impl Into<TerminalId>, data: impl Into<String>) -> Self
Builds a terminal output chunk with the required fields set.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
Sets or clears chunk-scoped metadata.