UpdateSessionNotification

Struct UpdateSessionNotification 

#[non_exhaustive]
pub struct UpdateSessionNotification { pub session_id: SessionId, pub update: SessionUpdate, pub meta: Option<Meta>, }
Available on crate feature unstable_protocol_v2 only.
Notification containing a session update from the agent.

Agents can send session updates at any point while the session exists.

See protocol docs: Agent Reports Output

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
session_id: SessionId

The ID of the session this update pertains to.

update: SessionUpdate

The actual update content.

meta: Option<Meta>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl UpdateSessionNotification

pub fn new(session_id: impl Into<SessionId>, update: SessionUpdate) -> Self

Builds UpdateSessionNotification with the required notification fields set; optional fields start unset or empty.

pub fn meta(self, meta: impl IntoOption<Meta>) -> Self

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility