#[non_exhaustive]pub struct Usage {
pub total_tokens: u64,
pub input_tokens: u64,
pub output_tokens: u64,
pub thought_tokens: Option<u64>,
pub cached_read_tokens: Option<u64>,
pub cached_write_tokens: Option<u64>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Token usage information for a prompt turn.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.total_tokens: u64Sum of all token types across session.
input_tokens: u64Total input tokens across all turns.
output_tokens: u64Total output tokens across all turns.
thought_tokens: Option<u64>Total thought/reasoning tokens
cached_read_tokens: Option<u64>Total cache read tokens.
cached_write_tokens: Option<u64>Total cache write tokens.
Implementations
Sourceimpl Usage
impl Usage
pub fn new(total_tokens: u64, input_tokens: u64, output_tokens: u64) -> Self
Available on crate feature
unstable_end_turn_token_usage only.Sourcepub fn thought_tokens(self, thought_tokens: impl IntoOption<u64>) -> Self
Available on crate feature unstable_end_turn_token_usage only.
pub fn thought_tokens(self, thought_tokens: impl IntoOption<u64>) -> Self
unstable_end_turn_token_usage only.Total thought/reasoning tokens
Sourcepub fn cached_read_tokens(
self,
cached_read_tokens: impl IntoOption<u64>,
) -> Self
Available on crate feature unstable_end_turn_token_usage only.
pub fn cached_read_tokens( self, cached_read_tokens: impl IntoOption<u64>, ) -> Self
unstable_end_turn_token_usage only.Total cache read tokens.
Sourcepub fn cached_write_tokens(
self,
cached_write_tokens: impl IntoOption<u64>,
) -> Self
Available on crate feature unstable_end_turn_token_usage only.
pub fn cached_write_tokens( self, cached_write_tokens: impl IntoOption<u64>, ) -> Self
unstable_end_turn_token_usage only.Total cache write tokens.