UserMessage

Struct UserMessage 

#[non_exhaustive]
pub struct UserMessage { pub message_id: MessageId, pub content: MaybeUndefined<Vec<ContentBlock>>, pub meta: MaybeUndefined<Meta>, }
Available on crate feature unstable_protocol_v2 only.
A user message upsert.

Only UserMessage::message_id is required. Other fields have patch semantics: omitted fields leave the existing message value unchanged, null clears or unsets the value, and concrete values replace the previous value. For a new messageId, omitted fields use client defaults. content is replaced as a whole array; send [] or null to clear it.

Message updates and chunks are applied in the order they are received. When a user_message update includes content, that array replaces any content previously accumulated for the message, including content from earlier chunks. Later chunks with the same messageId append to the current content.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
message_id: MessageId

A unique identifier for the message.

content: MaybeUndefined<Vec<ContentBlock>>

Complete replacement content for this message.

meta: MaybeUndefined<Meta>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl UserMessage

pub fn new(message_id: impl Into<MessageId>) -> Self

Builds UserMessage with the required fields set; optional fields start unset or empty.

pub fn content( self, content: impl IntoMaybeUndefined<Vec<ContentBlock>>, ) -> Self

Complete replacement content for this message.

pub fn meta(self, meta: impl IntoMaybeUndefined<Meta>) -> Self

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility