#[non_exhaustive]pub struct ClientCapabilities {
pub fs: FileSystemCapabilities,
pub terminal: bool,
pub plan: Option<PlanCapabilities>,
pub auth: AuthCapabilities,
pub elicitation: Option<ElicitationCapabilities>,
pub nes: Option<ClientNesCapabilities>,
pub position_encodings: Vec<PositionEncodingKind>,
pub meta: Option<Meta>,
}Expand description
Capabilities supported by the client.
Advertised during initialization to inform the agent about available features and methods.
See protocol docs: Client Capabilities
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fs: FileSystemCapabilitiesFile system capabilities supported by the client. Determines which file operations the agent can request.
terminal: boolWhether the Client support all terminal/* methods.
plan: Option<PlanCapabilities>unstable_plan_operations only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Whether the client supports plan_update and plan_removed session updates.
Optional. Omitted means the client does not advertise support.
Supplying {} means the client can receive both update types.
auth: AuthCapabilitiesunstable_auth_methods only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Authentication capabilities supported by the client.
Determines which authentication method types the agent may include
in its InitializeResponse.
elicitation: Option<ElicitationCapabilities>unstable_elicitation only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Elicitation capabilities supported by the client. Determines which elicitation modes the agent may use.
nes: Option<ClientNesCapabilities>unstable_nes only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
NES (Next Edit Suggestions) capabilities supported by the client.
position_encodings: Vec<PositionEncodingKind>unstable_nes only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
The position encodings supported by the client, in order of preference.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ClientCapabilities
impl ClientCapabilities
pub fn new() -> Self
Sourcepub fn fs(self, fs: FileSystemCapabilities) -> Self
pub fn fs(self, fs: FileSystemCapabilities) -> Self
File system capabilities supported by the client. Determines which file operations the agent can request.
Sourcepub fn terminal(self, terminal: bool) -> Self
pub fn terminal(self, terminal: bool) -> Self
Whether the Client support all terminal/* methods.
Sourcepub fn plan(self, plan: impl IntoOption<PlanCapabilities>) -> Self
Available on crate feature unstable_plan_operations only.
pub fn plan(self, plan: impl IntoOption<PlanCapabilities>) -> Self
unstable_plan_operations only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Whether the client supports plan_update and plan_removed session updates.
Omitted means the client does not advertise support.
Supplying {} means the client can receive both update types.
Sourcepub fn auth(self, auth: AuthCapabilities) -> Self
Available on crate feature unstable_auth_methods only.
pub fn auth(self, auth: AuthCapabilities) -> Self
unstable_auth_methods only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Authentication capabilities supported by the client.
Determines which authentication method types the agent may include
in its InitializeResponse.
Sourcepub fn elicitation(
self,
elicitation: impl IntoOption<ElicitationCapabilities>,
) -> Self
Available on crate feature unstable_elicitation only.
pub fn elicitation( self, elicitation: impl IntoOption<ElicitationCapabilities>, ) -> Self
unstable_elicitation only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Elicitation capabilities supported by the client. Determines which elicitation modes the agent may use.
Sourcepub fn nes(self, nes: impl IntoOption<ClientNesCapabilities>) -> Self
Available on crate feature unstable_nes only.
pub fn nes(self, nes: impl IntoOption<ClientNesCapabilities>) -> Self
unstable_nes only.UNSTABLE
NES (Next Edit Suggestions) capabilities supported by the client.
Sourcepub fn position_encodings(
self,
position_encodings: Vec<PositionEncodingKind>,
) -> Self
Available on crate feature unstable_nes only.
pub fn position_encodings( self, position_encodings: Vec<PositionEncodingKind>, ) -> Self
unstable_nes only.UNSTABLE
The position encodings supported by the client, in order of preference.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility