#[non_exhaustive]pub struct ForkSessionResponse {
pub session_id: SessionId,
pub modes: Option<SessionModeState>,
pub config_options: Option<Vec<SessionConfigOption>>,
pub meta: Option<Meta>,
}Expand description
UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Response from forking an existing session.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: SessionIdUnique identifier for the newly created forked session.
modes: Option<SessionModeState>Initial mode state if supported by the Agent
See protocol docs: Session Modes
config_options: Option<Vec<SessionConfigOption>>Initial session configuration options if supported by the Agent.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl ForkSessionResponse
impl ForkSessionResponse
pub fn new(session_id: impl Into<SessionId>) -> Self
unstable_session_fork only.Sourcepub fn modes(self, modes: impl IntoOption<SessionModeState>) -> Self
Available on crate feature unstable_session_fork only.
pub fn modes(self, modes: impl IntoOption<SessionModeState>) -> Self
unstable_session_fork only.Initial mode state if supported by the Agent
See protocol docs: Session Modes
Sourcepub fn config_options(
self,
config_options: impl IntoOption<Vec<SessionConfigOption>>,
) -> Self
Available on crate feature unstable_session_fork only.
pub fn config_options( self, config_options: impl IntoOption<Vec<SessionConfigOption>>, ) -> Self
unstable_session_fork only.Initial session configuration options if supported by the Agent.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
Available on crate feature unstable_session_fork only.
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
unstable_session_fork only.The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility