#[non_exhaustive]pub struct SessionInfoUpdate {
pub title: MaybeUndefined<String>,
pub updated_at: MaybeUndefined<String>,
pub meta: Option<Meta>,
}Expand description
Update to session metadata. All fields are optional to support partial updates.
Agents send this notification to update session information like title or custom metadata. This allows clients to display dynamic session names and track session state changes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: MaybeUndefined<String>Human-readable title for the session. Set to null to clear.
updated_at: MaybeUndefined<String>ISO 8601 timestamp of last activity. Set to null to clear.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility
Implementations
Sourceimpl SessionInfoUpdate
impl SessionInfoUpdate
pub fn new() -> Self
Sourcepub fn title(self, title: impl IntoMaybeUndefined<String>) -> Self
pub fn title(self, title: impl IntoMaybeUndefined<String>) -> Self
Human-readable title for the session. Set to null to clear.
Sourcepub fn updated_at(self, updated_at: impl IntoMaybeUndefined<String>) -> Self
pub fn updated_at(self, updated_at: impl IntoMaybeUndefined<String>) -> Self
ISO 8601 timestamp of last activity. Set to null to clear.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.
See protocol docs: Extensibility