pub trait IntoMaybeUndefined<T> {
// Required method
fn into_maybe_undefined(self) -> MaybeUndefined<T>;
}Expand description
Utility trait for builder methods for optional values.
This allows the caller to either pass in the value itself without wrapping it in Some,
or to just pass in an Option if that is what they have, or set it back to undefined.
Required Methods
Sourcefn into_maybe_undefined(self) -> MaybeUndefined<T>
fn into_maybe_undefined(self) -> MaybeUndefined<T>
Converts this value into a three-state builder argument.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl IntoMaybeUndefined<AbsolutePath> for Box<Path>
Available on crate feature unstable_protocol_v2 only.
impl IntoMaybeUndefined<AbsolutePath> for Box<Path>
Available on crate feature
unstable_protocol_v2 only.fn into_maybe_undefined(self) -> MaybeUndefined<AbsolutePath>
Sourceimpl IntoMaybeUndefined<AbsolutePath> for Cow<'_, Path>
Available on crate feature unstable_protocol_v2 only.
impl IntoMaybeUndefined<AbsolutePath> for Cow<'_, Path>
Available on crate feature
unstable_protocol_v2 only.fn into_maybe_undefined(self) -> MaybeUndefined<AbsolutePath>
Sourceimpl IntoMaybeUndefined<AbsolutePath> for OsString
Available on crate feature unstable_protocol_v2 only.
impl IntoMaybeUndefined<AbsolutePath> for OsString
Available on crate feature
unstable_protocol_v2 only.fn into_maybe_undefined(self) -> MaybeUndefined<AbsolutePath>
Sourceimpl IntoMaybeUndefined<AbsolutePath> for PathBuf
Available on crate feature unstable_protocol_v2 only.
impl IntoMaybeUndefined<AbsolutePath> for PathBuf
Available on crate feature
unstable_protocol_v2 only.fn into_maybe_undefined(self) -> MaybeUndefined<AbsolutePath>
Sourceimpl IntoMaybeUndefined<AbsolutePath> for String
Available on crate feature unstable_protocol_v2 only.
impl IntoMaybeUndefined<AbsolutePath> for String
Available on crate feature
unstable_protocol_v2 only.fn into_maybe_undefined(self) -> MaybeUndefined<AbsolutePath>
Sourceimpl IntoMaybeUndefined<PathBuf> for Box<Path>
impl IntoMaybeUndefined<PathBuf> for Box<Path>
fn into_maybe_undefined(self) -> MaybeUndefined<PathBuf>
Sourceimpl IntoMaybeUndefined<PathBuf> for Cow<'_, Path>
impl IntoMaybeUndefined<PathBuf> for Cow<'_, Path>
fn into_maybe_undefined(self) -> MaybeUndefined<PathBuf>
Sourceimpl IntoMaybeUndefined<String> for &String
impl IntoMaybeUndefined<String> for &String
fn into_maybe_undefined(self) -> MaybeUndefined<String>
Sourceimpl IntoMaybeUndefined<String> for &mut str
impl IntoMaybeUndefined<String> for &mut str
fn into_maybe_undefined(self) -> MaybeUndefined<String>
Sourceimpl IntoMaybeUndefined<String> for &str
impl IntoMaybeUndefined<String> for &str
fn into_maybe_undefined(self) -> MaybeUndefined<String>
Sourceimpl IntoMaybeUndefined<String> for Arc<str>
impl IntoMaybeUndefined<String> for Arc<str>
fn into_maybe_undefined(self) -> MaybeUndefined<String>
Sourceimpl IntoMaybeUndefined<String> for Box<str>
impl IntoMaybeUndefined<String> for Box<str>
fn into_maybe_undefined(self) -> MaybeUndefined<String>
Sourceimpl IntoMaybeUndefined<String> for Cow<'_, str>
impl IntoMaybeUndefined<String> for Cow<'_, str>
fn into_maybe_undefined(self) -> MaybeUndefined<String>
Sourceimpl IntoMaybeUndefined<Value> for &str
impl IntoMaybeUndefined<Value> for &str
fn into_maybe_undefined(self) -> MaybeUndefined<Value>
Sourceimpl IntoMaybeUndefined<Value> for Cow<'_, str>
impl IntoMaybeUndefined<Value> for Cow<'_, str>
fn into_maybe_undefined(self) -> MaybeUndefined<Value>
Sourceimpl IntoMaybeUndefined<Value> for String
impl IntoMaybeUndefined<Value> for String
fn into_maybe_undefined(self) -> MaybeUndefined<Value>
Sourceimpl<T: ?Sized + AsRef<OsStr>> IntoMaybeUndefined<AbsolutePath> for &T
Available on crate feature unstable_protocol_v2 only.
impl<T: ?Sized + AsRef<OsStr>> IntoMaybeUndefined<AbsolutePath> for &T
Available on crate feature
unstable_protocol_v2 only.