SessionUpdate

Enum SessionUpdate 

#[non_exhaustive]
pub enum SessionUpdate {
Show 16 variants UserMessageChunk(ContentChunk), AgentMessageChunk(ContentChunk), AgentThoughtChunk(ContentChunk), ToolCall(ToolCall), ToolCallUpdate(ToolCallUpdate), Plan(Plan), PlanUpdate(PlanUpdate), PlanRemoved(PlanRemoved), AvailableCommandsUpdate(AvailableCommandsUpdate), CurrentModeUpdate(CurrentModeUpdate), ConfigOptionUpdate(ConfigOptionUpdate), SessionInfoUpdate(SessionInfoUpdate), UsageUpdate(UsageUpdate), Notice(Notice), CompactionUpdate(CompactionUpdate), CompactionSummaryChunk(CompactionSummaryChunk),
}
Different types of updates that can be sent during session processing.

These updates provide real-time feedback about the agent’s progress.

See protocol docs: Agent Reports Output

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UserMessageChunk(ContentChunk)

A chunk of the user’s message being streamed.



AgentMessageChunk(ContentChunk)

A chunk of the agent’s response being streamed.



AgentThoughtChunk(ContentChunk)

A chunk of the agent’s internal reasoning being streamed.



ToolCall(ToolCall)

Notification that a new tool call has been initiated.



ToolCallUpdate(ToolCallUpdate)

Update on the status or results of a tool call.



Plan(Plan)

The agent’s execution plan for complex tasks. See protocol docs: Agent Plan



PlanUpdate(PlanUpdate)

Available on crate feature unstable_plan_operations only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

A content update for a plan identified by ID.



PlanRemoved(PlanRemoved)

Available on crate feature unstable_plan_operations only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Removal notice for a plan identified by ID.



AvailableCommandsUpdate(AvailableCommandsUpdate)

Available commands are ready or have changed



CurrentModeUpdate(CurrentModeUpdate)

The current mode of the session has changed

See protocol docs: Session Modes



ConfigOptionUpdate(ConfigOptionUpdate)

Session configuration options have been updated.



SessionInfoUpdate(SessionInfoUpdate)

Session metadata has been updated (title, timestamps, custom metadata)



UsageUpdate(UsageUpdate)

Context window and cost update for the session.



Notice(Notice)

Available on crate feature unstable_session_notices only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Advisory information for the user that is not part of session history.

No Client capability is required. Clients that do not understand or present notices may ignore them.



CompactionUpdate(CompactionUpdate)

Available on crate feature unstable_session_compaction only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

A context compaction has been created or updated.

Agents MUST only send this update when the Client advertised ClientSessionCapabilities::compaction.



CompactionSummaryChunk(CompactionSummaryChunk)

Available on crate feature unstable_session_compaction only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

A content block appended to a context compaction’s retained summary.

Agents MUST only send this update when the Client advertised ClientSessionCapabilities::compaction.