ToolCallUpdateFields

Struct ToolCallUpdateFields 

#[non_exhaustive]
pub struct ToolCallUpdateFields { pub kind: Option<ToolKind>, pub status: Option<ToolCallStatus>, pub title: Option<String>, pub name: Option<String>, pub content: Option<Vec<ToolCallContent>>, pub locations: Option<Vec<ToolCallLocation>>, pub raw_input: Option<Value>, pub raw_output: Option<Value>, }
Optional fields that can be updated in a tool call.

All fields are optional - only include the ones being changed. Collections (content, locations) are overwritten, not extended.

See protocol docs: Updating

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
kind: Option<ToolKind>

Update the tool kind.

status: Option<ToolCallStatus>

Update the execution status.

title: Option<String>

Update the human-readable title.

name: Option<String>
Available on crate feature unstable_tool_call_name only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Update the programmatic name of the tool being invoked.

This field is optional. Omitting it or sending null both mean that the existing name is left unchanged.

content: Option<Vec<ToolCallContent>>

Replace the content collection.

locations: Option<Vec<ToolCallLocation>>

Replace the locations collection.

raw_input: Option<Value>

Update the raw input.

raw_output: Option<Value>

Update the raw output.

Implementations

Source

impl ToolCallUpdateFields

pub fn new() -> Self

Builds ToolCallUpdateFields with the required fields set; optional fields start unset or empty.

pub fn kind(self, kind: impl IntoOption<ToolKind>) -> Self

Update the tool kind.

pub fn status(self, status: impl IntoOption<ToolCallStatus>) -> Self

Update the execution status.

pub fn title(self, title: impl IntoOption<String>) -> Self

Update the human-readable title.

pub fn name(self, name: impl IntoOption<String>) -> Self

Available on crate feature unstable_tool_call_name only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Update the programmatic name of the tool being invoked.

pub fn content(self, content: impl IntoOption<Vec<ToolCallContent>>) -> Self

Replace the content collection.

pub fn locations( self, locations: impl IntoOption<Vec<ToolCallLocation>>, ) -> Self

Replace the locations collection.

pub fn raw_input(self, raw_input: impl IntoOption<Value>) -> Self

Update the raw input.

pub fn raw_output(self, raw_output: impl IntoOption<Value>) -> Self

Update the raw output.