#[non_exhaustive]pub enum PlanUpdateContent {
Items(PlanItems),
File(PlanFile),
Markdown(PlanMarkdown),
Other(OtherPlanUpdateContent),
}Available on crate feature
unstable_protocol_v2 only.Expand description
Updated content for a plan.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Items(PlanItems)
Structured plan entries.
File(PlanFile)
Available on crate feature
unstable_plan_operations only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
A URI pointing to a file containing the plan.
Markdown(PlanMarkdown)
Available on crate feature
unstable_plan_operations only.UNSTABLE
This capability is not part of the spec yet, and may be removed or changed at any point.
Raw markdown content for the plan.
Other(OtherPlanUpdateContent)
Custom or future plan update content.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
Receivers that do not understand this content type should preserve the raw payload when storing, replaying, proxying, or forwarding plans, and otherwise ignore it or display it generically.
Implementations
Sourceimpl PlanUpdateContent
impl PlanUpdateContent
pub fn items(id: impl Into<PlanId>, entries: Vec<PlanEntry>) -> Self
pub fn file(id: impl Into<PlanId>, uri: impl Into<String>) -> Self
Available on crate feature
unstable_plan_operations only.pub fn markdown(id: impl Into<PlanId>, content: impl Into<String>) -> Self
Available on crate feature
unstable_plan_operations only.Trait Implementations
Sourceimpl Clone for PlanUpdateContent
impl Clone for PlanUpdateContent
Sourcefn clone(&self) -> PlanUpdateContent
fn clone(&self) -> PlanUpdateContent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlanUpdateContent
impl Debug for PlanUpdateContent
Sourceimpl<'de> Deserialize<'de> for PlanUpdateContent
impl<'de> Deserialize<'de> for PlanUpdateContent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PlanUpdateContent
Sourceimpl IntoV1 for PlanUpdateContent
Available on crate feature unstable_plan_operations only.
impl IntoV1 for PlanUpdateContent
Available on crate feature
unstable_plan_operations only.Sourceimpl JsonSchema for PlanUpdateContent
impl JsonSchema for PlanUpdateContent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PlanUpdateContent
impl PartialEq for PlanUpdateContent
Sourcefn eq(&self, other: &PlanUpdateContent) -> bool
fn eq(&self, other: &PlanUpdateContent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PlanUpdateContent
impl Serialize for PlanUpdateContent
impl StructuralPartialEq for PlanUpdateContent