#[non_exhaustive]pub enum SessionConfigOptionValue {
Id {
value: SessionConfigValueId,
},
Boolean {
value: bool,
},
Other(OtherSessionConfigOptionValue),
}unstable_protocol_v2 only.Expand description
The value to set for a session configuration option.
The type field acts as the discriminator in the serialized JSON form.
The type discriminator describes the shape of the value, not the option
kind. For example every option kind that picks from a list of ids
(select, radio, …) would use Id, while a future freeform
text option would get its own variant.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Id
A SessionConfigValueId string value (type: "id").
Fields
value: SessionConfigValueIdThe value ID.
Boolean
A boolean value (type: "boolean").
Other(OtherSessionConfigOptionValue)
Custom or future session configuration option value payload.
Values beginning with _ are reserved for implementation-specific
extensions. Unknown values that do not begin with _ are reserved for
future ACP variants.
Implementations
Sourceimpl SessionConfigOptionValue
impl SessionConfigOptionValue
Sourcepub fn id(id: impl Into<SessionConfigValueId>) -> Self
pub fn id(id: impl Into<SessionConfigValueId>) -> Self
Create an id option value (used by select and other id-based option types).
Sourcepub fn as_id(&self) -> Option<&SessionConfigValueId>
pub fn as_id(&self) -> Option<&SessionConfigValueId>
Return the inner SessionConfigValueId if this is a
Id value.