AgentCapabilities

Struct AgentCapabilities 

#[non_exhaustive]
pub struct AgentCapabilities { pub prompt: PromptCapabilities, pub mcp: McpCapabilities, pub session: SessionCapabilities, pub auth: AgentAuthCapabilities, pub providers: Option<ProvidersCapabilities>, pub nes: Option<NesCapabilities>, pub position_encoding: Option<PositionEncodingKind>, pub meta: Option<Meta>, }
Available on crate feature unstable_protocol_v2 only.
Capabilities supported by the agent.

Advertised during initialization to inform the client about available features and content types.

See protocol docs: Agent Capabilities

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
prompt: PromptCapabilities

Prompt capabilities supported by the agent.

mcp: McpCapabilities

MCP capabilities supported by the agent.

session: SessionCapabilitiesauth: AgentAuthCapabilities

Authentication-related capabilities supported by the agent.

providers: Option<ProvidersCapabilities>
Available on crate feature unstable_llm_providers only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Provider configuration capabilities supported by the agent.

By supplying {} it means that the agent supports provider configuration methods.

nes: Option<NesCapabilities>
Available on crate feature unstable_nes only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

NES (Next Edit Suggestions) capabilities supported by the agent.

position_encoding: Option<PositionEncodingKind>
Available on crate feature unstable_nes only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

The position encoding selected by the agent from the client’s supported encodings.

meta: Option<Meta>

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility

Implementations

Source

impl AgentCapabilities

pub fn new() -> Self

pub fn prompt(self, prompt: PromptCapabilities) -> Self

Prompt capabilities supported by the agent.

pub fn mcp(self, mcp: McpCapabilities) -> Self

MCP capabilities supported by the agent.

pub fn session(self, session: SessionCapabilities) -> Self

Session capabilities supported by the agent.

pub fn auth(self, auth: AgentAuthCapabilities) -> Self

Authentication-related capabilities supported by the agent.

pub fn providers( self, providers: impl IntoOption<ProvidersCapabilities>, ) -> Self

Available on crate feature unstable_llm_providers only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

Provider configuration capabilities supported by the agent.

pub fn nes(self, nes: impl IntoOption<NesCapabilities>) -> Self

Available on crate feature unstable_nes only.

UNSTABLE

This capability is not part of the spec yet, and may be removed or changed at any point.

NES (Next Edit Suggestions) capabilities supported by the agent.

pub fn position_encoding( self, position_encoding: impl IntoOption<PositionEncodingKind>, ) -> Self

Available on crate feature unstable_nes only.

UNSTABLE

The position encoding selected by the agent from the client’s supported encodings.

pub fn meta(self, meta: impl IntoOption<Meta>) -> Self

The _meta property is reserved by ACP to allow clients and agents to attach additional metadata to their interactions. Implementations MUST NOT make assumptions about values at these keys.

See protocol docs: Extensibility