#[non_exhaustive]pub struct CommandPermissionSubject {
pub command: String,
pub cwd: AbsolutePath,
pub tool_call_id: Option<ToolCallId>,
pub terminal_id: Option<TerminalId>,
pub meta: Option<Meta>,
}unstable_protocol_v2 only.Expand description
Permission request details for a command.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.command: StringThe command that would be run if permission is granted.
cwd: AbsolutePathThe absolute working directory for the command.
tool_call_id: Option<ToolCallId>The associated tool call, when known. Omitted and null are equivalent.
terminal_id: Option<TerminalId>The associated terminal, when already known. Omitted and null are equivalent.
meta: Option<Meta>The _meta property is reserved by ACP to allow clients and agents to attach additional
metadata to their interactions. Implementations MUST NOT make assumptions about values at
these keys. Omitted and null are equivalent and mean no subject metadata was provided.
See protocol docs: Extensibility
Implementations
Sourceimpl CommandPermissionSubject
impl CommandPermissionSubject
Sourcepub fn new(command: impl Into<String>, cwd: impl Into<AbsolutePath>) -> Self
pub fn new(command: impl Into<String>, cwd: impl Into<AbsolutePath>) -> Self
Builds command permission details with the required command and working directory.
Sourcepub fn tool_call_id(self, tool_call_id: impl IntoOption<ToolCallId>) -> Self
pub fn tool_call_id(self, tool_call_id: impl IntoOption<ToolCallId>) -> Self
Sets or clears the associated tool-call ID.
Sourcepub fn terminal_id(self, terminal_id: impl IntoOption<TerminalId>) -> Self
pub fn terminal_id(self, terminal_id: impl IntoOption<TerminalId>) -> Self
Sets or clears the associated terminal ID.
Sourcepub fn meta(self, meta: impl IntoOption<Meta>) -> Self
pub fn meta(self, meta: impl IntoOption<Meta>) -> Self
Sets or clears subject-scoped metadata.