#[non_exhaustive]pub struct Icon {
pub src: String,
pub mime_type: Option<String>,
pub sizes: Option<Vec<String>>,
pub theme: Option<IconTheme>,
}Available on crate feature
unstable_protocol_v2 only.Expand description
An optionally-sized icon that can be displayed in a user interface.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.src: StringA standard URI pointing to an icon resource.
mime_type: Option<String>Optional MIME type override if the source MIME type is missing or generic.
sizes: Option<Vec<String>>Optional sizes at which the icon can be used.
theme: Option<IconTheme>Optional theme this icon is designed for.
Implementations
Sourceimpl Icon
impl Icon
Sourcepub fn new(src: impl Into<String>) -> Self
pub fn new(src: impl Into<String>) -> Self
Builds Icon with the required source URI; optional display hints start unset.
Sourcepub fn mime_type(self, mime_type: impl IntoOption<String>) -> Self
pub fn mime_type(self, mime_type: impl IntoOption<String>) -> Self
Sets or clears the optional mimeType field.
Sourcepub fn sizes(self, sizes: impl IntoOption<Vec<String>>) -> Self
pub fn sizes(self, sizes: impl IntoOption<Vec<String>>) -> Self
Sets or clears the optional sizes field.
Sourcepub fn theme(self, theme: impl IntoOption<IconTheme>) -> Self
pub fn theme(self, theme: impl IntoOption<IconTheme>) -> Self
Sets or clears the optional theme field.